(*******************************************

	Cool`$Freight`  package


 *******************************************)



(* :Author: Thomas Cool *)
(* :Copyright: Copyright 1998 Thomas Cool *)
(* :Package Version: 1.06,  July 1998.*)
(* :Mathematica Version: 3.0.0 *)
(* :Keywords:    *)
(* :Limitation: *)
(* :License: use of this software file requires a license usually available
      by payment of $10 to Swift account ING.B.NL.2A 3736767 to the name of 
      Thomas Cool, Rotterdamsestraat 69, 2586 GH Scheveningen, Holland.
      Please inquire about the cost of packs. See the License[] function.
 *)

Needs["Cool`Common`"]

BeginPackage["Cool`$Freight`", Join[{"Cool`Arrowise`", "Cool`Freight`", "Cool`Transport`", "Cool`Statistics`Common`", "Cool`Physics`", "Cool`Databank`", "Cool`Economic`Common`"}, $Cool]]

ClassRates::usage = "ClassRates[Range] and ClassRates[] must be set if the $Freight databank routines are to work properly.
\nSet:
\nClassRates[Range] = list of pairs of distance[i] to distance[i+1]
\nClassRates[] = list of associated rates for these ranges
\n
\nYou can use:
\nClassRates[Set, list of distances] constructs the two arrays, using arbitrary ClassRates[] so that you can get an impression
\nClassRates[Table] prints these
\nClassRates[Find, d] finds the rate for distance d
\nClassRates[Class, c] finds the class rate statement for class code c
\nClassRates[Find, c, w] finds the rate for code c and weight w
\n
\nApart from these:
\nClassRates[Matrix, r, c, k:1] generates an arbitrary table of r rows and c colunms for rates for transport, with base r c k" 

UFC::usage = "UFC is a databank for ClassRates, using the Uniform Freight Classification"

Class::usage = "Class[Data] gives the first elements of UFC[Data], i.e. the codes"


$Freight::usage =  "Keyword for databank usage, combines $Trip and $Vehicle\n$Freight[i] creates a $Freight object i\n$Freight[$t, $v] combines $Trip object $t with $Vehicle object $v. In this case the $v cost information is not used to adapt $t\nTo use the cost information, by setting the $FreightPars to the value found in $v, use:\n$Freight[cs, hs, $v] for cs = list of class labels (as in Class[Data]), hs = list of Haul objects\n$Freight[t, lcs, lrs, $v] for t = Trip object, lcs = list of LiftCost objects, lrs = list of LiftRevenue objects"

$FreightAfterSum::usage = "$FreightAfterSum[List of rules] updates the settings of these rules"

$FreightDiagram::usage = "$FreightDiagram[opts] shows the relationships in the $Freight package by means of an arrow diagram, options for Show"

$FreightPars::usage = "To indicate a list of parameter values relevant for cost calculations. It has been defined as a databank object, so you can Explain it.\n$FreightPars[i] creates a $FreightPars object i\n$FreightPars[] is called by BeforeSum[LiftCost] and thus has to be set for operations like Databank[Sum, LiftCost]"

LiftCost::usage =  "Keyword for databank usage\nLiftCost[i] creates a LiftCost object i\nLiftCost is essentially a Lift with cost information added.\nWith the option BeforeSum -> LiftCostBeforeSum the cost is computed as a function of the duration of vehicle use and the cost directly dependent upon average speed, as in CostPerVKM"

LiftCostAfterSum::usage = "LiftCostAfterSum[List of rules] updates the settings of these rules"

LiftCostBeforeSum::usage = "LiftCostBeforeSum[List of rules] updates the settings of these rules, a.o. using $FreightPars[]"

LiftRevenueAfterSum::usage = "LiftRevenueAfterSum[List of rules] updates the settings of these rules"

LiftRevenueBeforeSum::usage = "LiftRevenueBeforeSum[List of rules] updates the settings of these rules"

LiftRevenue::usage =  "Keyword for databank usage\nLiftRevenue[i] creates a LiftRevenue object i\nLiftRevenue is essentially a Lift with revenue information added.\nWith the option BeforeSum -> LiftRevenueBeforeSum the revenue is computed as a function of the Class, UFC and ClassRates"

ToLiftCost::usage = "ToLiftCost[c, x_List] changes a Lift object x into a LiftCost object with class c\nToLiftCost[Expand, c, x_List, fp_List:$FreightPars[]]  expands the information using LiftCostBeforeSum. Note that $FreightPars has to be set. If x is a Haul object, then the result is {LiftCost[...lift part...], LiftCost[...handling...]}.\nIf c is a list, then it is assumed that x is a list of objects too, and the whole is threaded"

ToLiftRevenue::usage = "ToLiftRevenue[c, x_List] changes a Lift object x into a LiftRevenue object with class c\nToLiftRevenue[Expand, c, x_List] expands the information using LiftRevenueBeforeSum\nIf x is a Haul object, then automatically the lift part is taken.\nIf c is a list, then it is assumed that x is a list of objects too, and the whole is threaded"

TripTo$Trip::usage = "TripTo$Trip[t_List, costs_List, revs_List] where t is a Trip object, costs is a list of LiftCost objects and revs is a list of LiftRevenue objects"
 
HaulsTo$Trip::usage = "HaulsTo$Trip[cs_List, hs_List] where cs is a list of commodity classes per lift, and hs is a list of Haul objects. The Hauls are translated into Trip, LiftCost and LiftRevenue objects, after which TripTo$Trip is used. If a lift consists of more commodities classes, then this format requires the introduction of a mixed class"

HaulsToLiftCosts::usage = "HaulsToLiftCosts[cs_List, hs_List] uses HaulsToLifts before the classes are used to make LiftCost objects
\nHaulsToLiftCosts[Expand, cs_List, hs_List, p_List:{}] expands the information using LiftCostBeforeSum. Note that $FreightPars has to be set"


$Trip::usage =  "Keyword for databank usage\n$Trip[i] creates a $Trip object i"

$TripAfterSum::usage = "$TripAfterSum[List of rules] updates the settings of these rules. Note: BeforeSum -> {}, since it is assumed that $Trip is generated with HaulsTo$Trip, which makes the data consistent already"

$Vehicle::usage =  "Keyword for databank usage, combines Vehicle and $FreightPars\n$Vehicle[i] creates a $Vehicle object i"


Begin["`Private`"]
End[]
EndPackage[]
Print["This is a crippled package: it contains only the usage statements, no routines. Use of the proper software requires a user license.
See http://www.can.nl/~cool or write to Thomas Cool, Rotterdamsestraat 69, NL-2586 GH Scheveningen, Holland for ordering details"]
