(******************************************************************

	Cool`CES`  package


 ******************************************************************)



(* :Author: Thomas Cool *)
(* :Copyright: Copyright Thomas Cool *)
(* :Package Version: 2.01,  February 1997.*)
(* :Mathematica Version: 2.2.2 *)
(* :Keywords:    *)
(* :Limitation:
*)
(* :Comments:
(1) A first possible solution strategy is to take the most general form, solve this for various properties, and then collapse these results for various specific parameter values. However, the latter would multiply the task for the Limit procedure in Mathematica. It appears that for most cases it is better to first solve the limit, and then repeat the derivation of properties for the various subcases.
(2) Algebraic manipulations are only possible for nonnumeric variables and parameters, i.e. when such items are known by name. For example Cost and Profit and Demand functions can be determined in that manner. However, the latter cannot be derived when numeric input is given, when variables and parameters are not known by name. Therefor, explicit statements for such results must be provided in the package. This means that the author has performed the algebraic manipulations, and has put the result into separate functional statements. 
*)

(* :License: use of this software file requires a license, usually available
      by payment of $10 to Swift account ING.B.NL.2A 3736767 to the name of 
      Thomas Cool, Rotterdamsestraat 69, 2586 GH Scheveningen, Holland.
      Please inquire about the cost of file packs. See the License[] function. *)

Needs["Cool`Common`"]

BeginPackage["Cool`CES`", Join[{"Cool`Economic`Common`"}, $Cool]]


Options$CES::usage = "Makes options available for a ResetOptions[CES]; the current settings of Options[Aggregator] are taken; so perhaps you wish to ResetOptions[Aggregator] first"

S::usage = "Keyword default value in Ces -> S in Options[CES], denoting the elasticity of substitution between the input factors"

Ces::usage = "Keyword for the constant elasticity of substitution in the Options[CES]"

CES::usage = "CES[opts___Rule] calls the Constant Elasticity of Substitution function using default options as set in Options[CES].\nCES[A_, c_, x_, S_, v_:1] gives the  function with scale factor A, factors x, their coefficients c (usefully summing to 1), the elasticity S, and the returns to scale parameter v.\nWhen CESlimitQ[S] then the function takes a special form (Leontief, CD or Line). The call of the function also creates the CESterm which excludes scale and powers."

CESlimitQ::usage = "CESlimitQ[S] := MemberQ[{0,0.,1,1.,Infinity}, S]"

CESterm::usage = "CESterm is the inner term, i.e. (Aggregate / A)^(1/v). CESterm is defined within the call of the CES[] function, and keeps its current value until the next call."

CEStermRule::usage = "CEStermRule[opts___Rule] gives the rule CESterm -> function[Aggregate] for the relevant form. The latest CESterm is used, i.e. of the latest CES[] call. This means that there need not be a relation with the parameters given in the present call of CEStermRule.\nAnother input format is CEStermRule[A, s, v:1]."

CESContours::usage = "1) CESContours[levels_List, width, rulei___Rule] calls ContourPlot with Contours -> levels, for {xi, 1, width}, where width must be a number. Options rulei are only relevant for the CES function and not for display. Display is suppressed with DisplayFunction -> Identity.\n2)CESContours[levels_List, width, rules__List, opts___Rule] maps CESContours onto the rules, and displays normally, using opts. For example:\n   CESContours[{50}, 400, {rule11,...}, {rule21, ...}, ..., AxesOrigin -> {0, 0}]\nFor both, the Factors -> {x1, ... } must be set such that only two elements are Symbols and all other are numbers."

CheckES::usage = "CheckES[S] checks on the Sign of S (nonnegative value expected) and substitutes 0. -> 0 and 1. -> 1"

DCES::usage = "DCES[opts___Rule] takes defaults from Options[CES], differentiates the CES function to factor xi, in Factor -> xi, and substitutes Aggregate == CES[...] back into the result.\nAn alternative input format is DCES[Hold[CES[A, c, x, S, v_:1]], xi]"

FactorDemand::usage = Key[AddedUsage, FactorDemand, "Two special non-rule formats are:\nFactorDemand[Hold[CES[A, c, x, S, v:1]], Aggregate, Position_Integer]\nFactorDemand[Profit, Aggregate_, AggregatePrice_, FactorPrice_, Scale_, FactorCoef_, S_, Rts_:1] gives the demand assuming profit maximisation, but without other prices and without recalculating the level of production."]

SetOptionsCESSector::usage = "SetOptionsCESSector[i] performs a SetOptions for Sector i. SetOptionsCESSector[] gives options for the aggregate, thus with S[], Scale[], etc. SetOptionsCESSector[None] returns pure symbols S, Scale, etc. (Note that you cannot use a pure symbol S for the aggregate and a functional form S[i] for a sector. For, when S gets a value, S = 100, then you get 100[i] ...)"


Results$CES = Results$Aggregator;
ResetResults[CES];
Begin["`Private`"]
End[]
EndPackage[]
Print["This is a crippled package: it contains only the usage statements, no routines. Use of the proper software requires a user license.
See http://www.can.nl/~cool or write to Thomas Cool, Rotterdamsestraat 69, NL-2586 GH Scheveningen, Holland for ordering details"]
