(*******************************************

	Cool`Databank`  package


 *******************************************)



(* :Author: Thomas Cool *)
(* :Copyright: Copyright 1997 Thomas Cool *)
(* :Package Version: 1.03,  July 1998.*)
(* :Mathematica Version: 3.0.0 *)
(* :Keywords:    *)
(* :Limitation: *)
(* :License: use of this software file requires a license usually available
      by payment of $10 to Swift account ING.B.NL.2A 3736767 to the name of 
      Thomas Cool, Rotterdamsestraat 69, 2586 GH Scheveningen, Holland.
      Please inquire about the cost of packs. See the License[] function.
 *)

Needs["Cool`Common`"]

BeginPackage["Cool`Databank`", Join[{}, $Cool]]

AfterSum::usage = "Keyword in Options[...your databank...] to indicate the operations to be performed after summing the entries. See Databank[Sum,...]\nAfterSum[db:Automatic] gives these settings for db"

BeforeSum::usage = "Keyword in Options[...your databank...] to indicate the operations to be performed before summing the entries. See Databank[Sum,...]\nBeforeSum[db:Automatic] gives these settings for db"

DataMold::usage = "Keyword in Options[...your databank... ] that identifies the keys of your databank.\nThus a databank MyOwn will require Options[MyOwn] = {DataMold -> {...}}. See SetDatabank. \nNB. Often it is useful to define yourself MyOwn[DataMold] = ..., and set the option as SetOption[MyOwn, DataMold -> MyOwn[DataMold]]"

SetDatabank::usage = "SetDatabank[x_List, data_List:{}, db_Symbol:Automatic]\n(1) sets db[Data] = data,\n(2) sets DataMold -> x in Options[db]\n(3) warrants that the databank option of SetDatabank is set with value db, with default db = Databank
\nThis is equivalent to doing yourself, if you create a new databank e.g. MyOwn:
\n              MyOwn[Data] = data
\n              Options[MyOwn] = {DataMold -> {...keys...}}
\n              SetOptions[SetDatabank, Databank -> MyOwn]
\n
\nNote: This routine only helps structuring the proceedings. Of course, you can always redefine db[Data] and the options"

Databank::usage = 
"Databank relies on a separate storage of the keys and the values. There is no use in adding the keys to all the data, since these keys remain the same. With the same structure (that is defined by you) you can however still use the keys for replacing and other manipulating.
\n
\nThe default situation is:
\nStart by:           SetDatabank[{...keys...}, {datalist1, datalist2, ...}]
\nResult: The keys are stored in Options[Databank] and the data are available in Databank[Data]
\n
\nIf your create a new databank, e.g. MyOwn, then e.g.:
\nEvaluate:            SetDatabank[{...keys...}, {data}, MyOwn]
\nResult: The keys are stored in Options[MyOwn] and the data are available in MyOwn[Data]
\n
\nNB. Operations that work for the whole databank are:
\nDatabank[Query, key (, db)] for retrieving values
\nDatabank[ReplaceAll, {new__Rule} (, db)] for replacing the values with new ones. Per data entry you can use existing values in the databank by referring to the keys only.
\nDatabank[ReplaceAll, head (, db)] for the head of a function that has a list of rules as input (as Explain[entry]) and that creates a new list of rules.
\nDatabank[Plus (, db)] adds all entries (i.e. Plus @@ db[Data])
\nDatabank[Sum  (, db}] first performs BeforeSum operations, then adds, and then performs AfterSum operations, as specified in Options[db].
\nDatabank[FromMold (, db)] adjusts all entries to the DataMold mold
\nDatabank[Switch, db (, data_List)] switches to db presuming a predefined DataMold (while the db[Data] may be updated to data).
\n
\nNB. The default db value is taken from the Databank option in Options[SetDatabank]
\nNB. Datalists can be structured. The present implementation allows a structure of only two levels deep, for example {d1, {d2,...}, d3, {...}, ...}
\nNB. To update a databank: Databank[Data] = value, or, MyOwn[Data] = value. An alternative is to use Upd[...]
\nNB. Be aware that Databank[Plus, ...] and Databank[Sum, ...] generate a lower dimension, so that it is not wise to use Upd here. However, if the Upd -> True option is set, the intermediate result of before summing is stored in the databank
\n
\nNB. Operations that work on a single data entry with proper structure are:
\nDatabank[Query, key, y_List (, db)] for retrieving the value
\nDatabank[Explain, y_List (, db)] for an explanation keyi -> valuei for all values while retaining the entry structure
\nExplain[y_List] gives this explanation in Flattened format
\nDatabank[Replace, y_List, {new__Rule} (, db)] for replacing the values in a single entry y with new ones, where you can use existing values in y
\nDatabank[Replace, y_List, head (, db)] for the head of a function that has Explain[y] as input, and that creates a new list of rules for replacement
\nDatabank[FromMold, y_List (, db)] adjusts an incomplete y to the proper DataMold mold
\nDatabank[Expand, y_List, (, db)] first FromMold's and then Replace with the BeforeSum rules
\nDatabank[Add, data_List, (, db)] is similar to Databank[Sum, (,db)] but then for a datalist that need not be called db[Data]
\n
\nExample: SetDatabank[{Tan, {Sin, Cos}}]
\n         Databank[Data] = {{2, {1, x}},  {y, {0.5, -1}} }"

Explain::usage = "Databank[Explain, y (, db)] for an explanation keyi -> valuei for all values while retaining the entry structure\nExplain[entry (, db)] for a Flattened result"

Upd::usage = "Upd[x__] sets db[Data] = Databank[x__] where the db is identified by means of the last item in the sequence, or the current database if this item is not recognised as a Databank object (namely without options declared)\nUpd[] performs Upd[FromMold] and then Upd[ReplaceAll, BeforeSum[]]"

ShowData::usage = "For a TableForm display of Databank data, using the 
DataMold for TableHeadings. If no databank is mentioned, then the current one is taken, and options are passed on to TableForm. NB. The data structure is Flattened, for display only. There are different formats:
\n   ShowData[db_Symbol, opts] plots the data in columns
\n   ShowData[Sum, db_Symbol, opts] adds the AfterSum result
\n   ShowData[x_][db_Symbol, opts] for a Take[data, x] selection
\n   ShowData[Transpose, db_Symbol, opts] transposes
\n   ShowData[x_][Transpose, db_Symbol, opts] transposes & selects entries
\n   ShowData[Transpose, data_List, db_Symbol, opts] for arbitrary data
\n   ShowData[x_][Transpose, data_List, db_Symbol, opts] selects entries"

Begin["`Private`"]
End[]
EndPackage[]
Print["This is a crippled package: it contains only the usage statements, no routines. Use of the proper software requires a user license.
See http://www.can.nl/~cool or write to Thomas Cool, Rotterdamsestraat 69, NL-2586 GH Scheveningen, Holland for ordering details"]
