(*********************************************************************

	Cool`Declare`  package


 *********************************************************************)



(* :Author: Thomas Cool *)
(* :Copyright: Copyright 1995/97 Thomas Cool *)
(* :Package Version: 2.08 August 1998.*)
(* :Mathematica Version: 3.0.0 *)
(* :Keywords:    *)
(* :Limitation: *)
(* :License: use of this software file requires a license usually available
      by payment of $10 to Swift account ING.B.NL.2A 3736767 to the name of 
      Thomas Cool, Rotterdamsestraat 69, 2586 GH Scheveningen, Holland.
      Please inquire about the cost of packs. See the License[] function. *)


BeginPackage["Cool`Declare`", {"Cool`Common`", "Cool`Context`"}]

Cool::usage = "Cool[xi, ...] shows the contents of Cool`xi`, and if needed loads the package(s). Input xi can be Symbol, or String with or without back-apostrophe. To prevent name conflicts, input xi_Symbol is first removed.\nCool[All] will load the CoolPack` package, where all routines of the various Cool packages are assigned the Stub-attribute. \nNote: In the Traditional Form of Mathematica 3.0 the printing order is messed up when more than one package is called in one statement."

UsageInPackage::usage = "UsageInPackage[inputfile_String] reads a package, and returns a list of commands that have usage declarations"

DeclarePacs::usage = "1) DeclarePacs[Cool] reserves command names for the Cool Packages. A DeclarePackage statement assigns the Stub Attribute so that the relevant package is read when the command is actually called.\n2) DeclarePacs[Set, Cool] writes DeclarePackage statements to the file CoolPack.m. Note that you may have to use SetDirectory[].\n3) DeclarePacs[outputfile_String, location_String, dir_String, commands_ListOfStrings] writes a file with DeclarePackage statements. As inputs, the files location<>dir<>commands[[i]] are read by UsageInPackage. A DeclarePackage is stated per context dir<>commands[[i]]. Note: the DeclarePackage statements are only executed by loading the produced file (Get[outputfile])."

CoolPack::usage = "Evaluate CoolPack to get a list of the packages"

InstallCoolPackStyle::usage = "InstallCoolPackStyle[] checks whether the CoolPackStyle.nb is in the SystemFiles Stylesheets directory, and if not, copies it to that place from the Cool..Install directory"

SearchInPackages::usage = "SearchInPackages[loc_String, nam1_String, nam2_List, items_List, combine_:False] searches for items (always submitted to ToString) in the file loc <> nam1 <> nam2 (.m), and prints lines of occurrence. If combine === True then only combinations are printed."

Begin["`Private`"]


takefirst[x_] := Module[{f = StringPosition[x, "::usage"]}, 
		StringTake[x, f[[1,1]]-1]];

UsageInPackage[file_String] := Module[{a, x, pos},
	a = ReadList[file, String];
	pos = Position[a, "Begin[\"`Private`\"]"];
	If[pos =!= {}, a = Take[a, pos[[1,1]] ]];
	a = Select[a, (StringPosition[#, "::usage"] =!= {})&] ;
	b = Select[a, (StringPosition[#, "Key[AddedUsage"] === {})&] ;
	Map[takefirst, b]]

DosName[x_] :=Module[{a = x}, 
		If[StringTake[a, -1] === "`", a = StringDrop[a, -1] <> ".m"];
		StringReplace[a, "`" -> "\\"]]

DeclarePacs[fln_String, loc_String, nam1_String, nam2_List] := 

	Module[ {m, nam, vars },
	m = OpenWrite[fln, PageWidth -> Infinity];
	Do[nam = nam1<>nam2[[i]];
		vars = UsageInPackage[DosName[loc <> nam]];
		Write[m, OutputForm["DeclarePackage[\"" <> nam <> "\"," ] ];
		Write[m, vars];
		Write[m, OutputForm[ "]"]];
		Print["Processed " <> ToString[i] <> ":  " <> nam],
		  {i, 1, Length[nam2]}];
	Close[m] ]  

SearchInPackages[loc_String, nam1_String, nam2_List, items_List, 
	combine_:False] := 
	Module[ {nam, vars, its, a, x},
	its = Map[ToString, items]; 
	Do[nam = nam1<>nam2[[i]];
		a = ReadList[DosName[loc <> nam], String]; 
		If[combine, 
			Do[a = Select[a, (StringPosition[#, its[[j]] ] =!= {})&], 
			{j, 1, Length[its]}]; Map[Print, a],
			(*else*)
			Do[x = Select[a, (StringPosition[#, its[[j]] ] =!= {})&];
			Map[Print, x], {j, 1, Length[its]}]];
		Print["Processed " <> nam],  {i, 1, Length[nam2]}]]  


CoolPac1 = {"Arrowise`", "Chi2`", "Common`", "Context`",  "CrossTable`", "Decision`", "Declare`", "Dbase`", "Dictionary`", "DifData`", "Finance`", "FlatRate`", "Inference`", "List`", "Logic`", "Lseqlist`", "Manager`", "Minimax`", "MissingData`", "PackLine`", "ReadData`", "Sampling`", "ShowPlan`", "Statistics`Common`", "Time`",  "Tool`"};

CoolPac2 = {"AGE`", "Calculus`", "CES`", "ShiftCES`", "Economic`Common`", "Economic`Optimise`", "IADS`", "Lagrange`", "Leontief`", "LevelCES`"};

CoolPac3 = {"Arima`", 
	"Chaindex`" (* exclude: "Data`USA`" & "Data`Holland`" *), 
	 "Data`", "Estimate`", "Graphics`", "GenePro`", 
	"GenePro`Estimation`" (* exclude: "GenePro`Cart`" *) ,  
	"Lags`", "Matrices`",  "Model`", "Neural`", "OneLag`" };

CoolPac4 = {"Cartel`", "Databank`", "Economic`Graphics`", 
	"Economic`Macro`", 
	"Freight`", "$Freight`", "Operations`", "LP`", "Money`",
	"PeakLoad`", "Physics`", "Pythagoras`", "Probability`",
	"Queue`", "Shipping`", "Taxes`", "TScience`", "Transport`", 
	"Voting`" , "WorldMap`"
	};


CoolPack = Union[CoolPac1, CoolPac2, CoolPac3, CoolPac4];

DeclarePacs[Set, Cool] := DeclarePacs["PackAdds\\Cool\\CoolPack.m", 
				"PackAdds\\",  "Cool`", CoolPack]

DeclarePacs[Cool] := Get["PackAdds\\Cool\\CoolPack.m"]

Cool[All] := (Off[DeclarePackage::aldec]; Off[Needs::nocont];
		Needs["Cool`CoolPack`"]; 
		On[DeclarePackage::aldec]; On[Needs::nocont];)

Cool[x_Symbol] := Module[{a, b}, a = ToString[x]; b ="Cool`" <> Cure[a];
	If[(!MemberQ[$ContextPath, b]) && ("Cool`Data`" =!= b), Remove[x]]; 
	Contents[b]]

Cool[x_String] := Contents["Cool`" <> Cure[x]]

Cool[x__] := Cool /@ {x}

InstallCoolPackStyle[] :=

If[{} ===
FileInformation[ToFileName[{$TopDirectory, "SystemFiles", "FrontEnd", "StyleSheets"}, "CoolPackStyle.nb"]],
Print["Copy of CoolPackStyle.nb to the proper location"];
CopyFile[
ToFileName[{$TopDirectory, "AddOns", "Applications", "Cool", "Documentation", "English", "Install"}, "CoolPackStyle.nb"],
ToFileName[{$TopDirectory, "SystemFiles", "FrontEnd", "StyleSheets"}, "CoolPackStyle.nb"] ],
Print["CoolPackStyle.nb is in the proper location"]
];


End[]

EndPackage[]
