(******************************************************************

	Cool`Economic`Common`  package


 ******************************************************************)



(* :Author: Thomas Cool *)
(* :Copyright: Thomas Cool *)
(* :Package Version: 3.07, July 1998.*)
(* :Mathematica Version: 3.0.0 *)
(* :Keywords:  Economics  *)
(* :Limitation:  *)
(* :License: use of this software file requires a license usually available
      by payment of $10 to Swift account ING.B.NL.2A 3736767 to the name of 
      Thomas Cool, Rotterdamsestraat 69, 2586 GH Scheveningen, Holland.
      Please inquire about the cost of packs. See the License[] function. *)
(* :Comments: the Aggregator initially defines on itself *)


Needs["Cool`Common`"]

BeginPackage["Cool`Economic`Common`", $Cool]

Options$Aggregator::usage = "Stores the options at startup, for a ResetOptions[Aggregator]"

Aggregator::usage = "Keyword for the option that selects the aggregator"
Scale::usage = "Initial value Constant -> Scale in the Options[Aggregator]"
NumberOfFactors::usage = "Keyword for a rule for the number of factors. Default in Options[Aggregator] is NumberOfFactors -> 2"

Aggregate::usage = Key[AddedUsage, Aggregate, "1) Keyword in Options[Aggregator] for the level of output or utility. Thus Aggregate == f[....] denotes the value of the function f.\n2) FactorDemand[... Dual -> Aggregate]: has the meaning that the dual demand function contains only prices and the aggregate (and no explicit indicator for Cost or Profit)."]

AggregatePrice::usage = "Keyword for the price of the Aggregate"



Factors::usage = "Keyword in ResetFactors[]"
FactorCoefficients::usage = "Keyword in ResetFactors[]"
FactorPrices::usage = "Keyword in ResetFactors[]"
FactorX::usage = "Element in Factors"
FactorP::usage =  "Element in FactorPrices"
FactorC::usage =  "Element in FactorCoefficients"

FactorPowers::usage = "Keyword that may be added into Options[Aggregator]"
FactorE::usage = "Keyword that may be added into Options[Aggregator], likely for exponential terms"

Factor::usage = Key[AddedUsage, Factor, "Factor -> (default FactorX[1]) occurs in Options[aggregator] for the selection for FactorDemand"]
Return::usage = Key[AddedUsage, Return, "Return -> (default 1) occurs in Options[aggregator] to denote the returns to scale. See RTS."]
Constant::usage = Key[AddedUsage, Constant, "Constant -> (default Scale) occurs in Options[aggregator] as the constant markup of the Aggregator"]


Dual::usage = "Keyword.  In Options[aggregator] it can be used to specify what kind of duality result is to be taken."

FactorLabels::usage = "Keyword for all FactorX[i] labels, also those which are perhaps not explicitly used when there are levels."
FactorSettings::usage = "Keyword for {FactorX[i] -> valuei, ... }"
Levels::usage = "Keyword. Levels -> {n1, n2, ..., n} when level i has ni factors."


Options$Aggregator = Sort[{ 
		Aggregator -> Aggregator, 	         (* short: f *)
		Aggregate -> 1,					(* short: y *)
		AggregatePrice -> 1,				(* short: py *)
		Constant -> Scale, 				 (* short: c *)
		DemandFunction -> Cost,
		Dual -> Cost,
		DualQ -> Null,  (* default useful for Properties *)
		Cost -> Cost,
		Return -> 1,  					 (*short: v *)
		NumberOfFactors -> 2,
		Factors -> Array[FactorX, 2],               (* short: x *)
		FactorPosition -> Automatic,
		Factor -> FactorX[1],
		FactorPrices -> Array[FactorP, 2],      (* short: p or px*)
		ResetFactors -> {{"FactorCoefficients", "FactorC"}}  (* short: b *)
		}]

Options[Aggregator] = Options$Aggregator

AES::usage = "AES[opts___Rule] gives the Allen Elasticity of Substitution using AES[i, j] = dLog[xi] / dLog[pj] / CSj where CS is the minimal cost share. Default option for the derivative selection is D -> FactorP[2]"

AUES::usage = "AUES[opts___Rule] gives the Allen Elasticity of Substitution using Uzawa 1962 AES[i, j] = C * Cij / (Ci Cj) where C is minimal cost and Ci the derivative on price i. Default option for the derivative selection is D -> {FactorP[1], FactorP[2]}"

AverageInventory::usage = "AverageInventory[q, ss:0] for stable stock ss (safety, pipeline) and q/2 the average variable stock"

BudgetEquation::usage = "BudgetEquation[opts___Rule] gives the budget equation using only the keywords of the Options[current aggregator], with Profit giving the difference between py*y and px.x"

Capital::usage = "Keyword"

Consumption::usage = "Keyword for an aggregator with a specific application"
Production::usage = "Keyword for an aggregator with a specific application"
Utility::usage = "Keyword for an aggregator with a specific application"
NumberOfSectors::usage = "Keyword for the number of commodities in the model."
Resources::usage = "Keyword"
Sector::usage = "Keyword"

Cost::usage = "Cost[opts___Rule] gives cost:  px.x\nCost[Function, opts___Rule] gives px.x where one factor xi has been solved as a function of the output level and the other input factors. Factor xi is selected by FactorPosition."

CostElasticity::usage = "CostElasticity[opts___Rule] gives the cost elasticity of Factor in the FactorDemand[Cost, opts]. This would be the most general statement that can be used to determine the income elasticity."

CurrentAggregator::usage = "CurrentAggregator[opts] gives the Aggregator option setting. Opts can be Blank, a sequence of rules or a list of the former. The default (Blank) value is taken from Options[Aggregator]."

Demand::usage = "Keyword."

DemandFunction::usage = "Keyword in Options[Aggregator] to indicate the type of demand function to use for the factors; known selections are Function, Price, Cost and Profit.\nCan also be used to define own demand functions."

DualSelector::usage = "DualSelector[{opts___Rule}] selects known combinations of demand functions and Dual type from opts, updating the latter. Output is {DemandFunction type, Dual type, optsnew}. Default is Cost for all."

DualQ::usage = "Keyword. True if the aggregator is indirect (dual), False if direct, Null if unknown" 

ES::usage = "ES[f, xi, xj] or ES[g[..., xi, ..., xj, ...], xi, xj] gives the direct Elasticity of Substitution of f[x,y] or g[...] evaluated at xi and xj (McFadden (1963)). For n=2, the ES is equal to the AES, but in general not." 

FactorDemand::usage = "FactorDemand[Assumption, rules] gives the demand for a factor, under Assumption. The default aggregator is taken from Options[Aggregator], and may also be given as Aggregator -> aggregator in the current rules. \nAssumption can be:\n(f = current aggregator): use the setting of DemandFunction -> ...;\n((f,) Function): use only the functional relationship to select a point on the efficiency frontier;\n((f,) Price): use py D[f, xi] == pi for i only to solve for xi ;\n((f,) Cost): use cost minimisation;\n((f,) Profit): use profit maximisation.\nThe other inputs would be rules. The factor demanded is selected by FactorPosition. The option Dual -> ... (default: Cost, alternative e.g. Aggregate) may specify the kind of duality applied. If DualQ -> True then Roy's Rule is applied.\nOutput: factor -> value." 

(* Programming note: Use FactorDemand[Dual[g], ...] to specify a dual aggregator demand within the application package. End-Users will not use this form, but rely on FactorDemand[...] or FactorDemand[f, ...] and the option DualQ -> ....  Thus, it is up to the programmer to translate this into a specific FactorDemand[Dual[g], ...] call. *)

FactorPosition::usage = "(1) FactorPosition[copt_List] is a routine that gives the position of Factor within Factors;\n(2)FactorPosition -> ... is an option within Options[current aggregator] that controls the routine.\nIf FactorPosition -> Automatic then the position of the factor is searched for. Alternatively FactorPosition -> n. This setting is useful when Factors has numerical values, some of which may be equal."

Intermediate::usage = "Keyword"


Inventory::usage = "Keyword"

InventoryModel::usage = "InventoryModel[x___Rule] is a SolveFrom application, using, in real values:
\n	Demand + DInventory == Production,
\n	DInventory == AverageInventory - OldInventory,
\n	Production == LabourProductivity Labour,
\n	Turnover == Demand / AverageInventory,
\n	NPeriodsOfSupply == AverageInventory / Demand.
\n\nUse this with e.g.
\n	AverageInventory -> alpha Sqrt[Demand],
\n	Demand -> DemandPerCapita Labour / Participation"

DInventory::usage = "Keyword, e.g. in InventoryModel for change in stocks (s - s(-1))"

OldInventory::usage = "Keyword, e.g. in InventoryModel for s(-1)"
Labour::usage = "Keyword"
LabourProductivity::usage = "Keyword for the average"


MarginalCost::usage ="MarginalCost[(f,) opts], a common term in economics for D[Cost[Factor -> x], x] with f the aggregator function"

MarginalProduct::usage ="MarginalProduct[(f,) opts], a common term in economics for D[f[x], x] with f the aggregator function"

MarkUp::usage = "Keyword. Basically Revenue == (1 + MarkUp) Cost"

MaximalProfit::usage = "MaximalProfit[(aggregator,) opts___Rule] gives the results of profit maximisation with given AggregatePrice and FactorPrices. The default aggregator is taken from Options[Aggregator], and may also be given as Aggregator -> aggregator. Output is conditional: If[ returns to scale >= 1, (*then limited by resources*) Infinity, (*else*) {Aggregate -> ..., MinimalCost -> ..., MaximalProfit -> ...}]"

MinimalCost::usage = "MinimalCost[(aggregator,) opts___Rule] gives the minimal cost to produce Aggregate with given FactorPrices. The default aggregator is taken from Options[Aggregator], and may also be given as Aggregator -> aggregator. (Note: minimal cost factor demand x*[y, p] would follow from gradient[MinimalCost[]], following Hotelling 1932 and Shephard 1953.)"

NPeriodsOfSupply::usage = "NPeriodsOfSupply[d, i, p:1] for total demand d over the period p, and inventory i. If i = a is the average inventory over the period, then this gives the average number of periods of supply"

Nominal::usage = "Keyword. Use as Demand[Nominal] versus Demand[Real]"

Optimal::usage = "Keyword. Use this like Optimal[Price] = ... or Price[Optimal] = ..."

Price::usage = "Keyword."

PriceElasticity::usage = "1) PriceElasticity[opts___Rule] gives the own price elasticity of Factor, i.e. partial derivative\n   dlog[DemandFunction[]]/dlog[FactorP[i]]\nThe function uses DualSelector.\n2) PriceElasticity is a keyword for Properties, giving the own price elasticities array taken from the (direct) aggregator"

Profit::usage = "Profit[opts___Rule] gives profit: py*f[x] - px.x where f is the current aggregator.\nProfit[Function, opts___Rule] gives profits as a function of output y = f[x], where cost has been solve for factor xi\nNote: default AggregatePrice is 1."

Properties::usage = "Properties[opts___Rule] gives some properties of the current aggregator using explicit differentiation. Output is {Return -> returns to scale, Share -> list of cost shares, PriceElasticity -> list of own prices elasticities}"

Quantity::usage = "Keyword."

Share::usage = Key[AddedUsage, Share, "Share -> occurs in the output of Properties giving the cost shares of the factors, found by differentiating: x f' / Sum[x f']"]

Supply::usage = "Keyword."

ResetFactors::usage = "ResetFactors[opts_Rule] resets options in Options[currentAggregator] which pertain to the factors. Options[ResetFactors] give control over the NumberOfFactors and Clearing.\nThe options Aggregator -> ... and ResetFactors -> (...list of list of strings...)  are taken from Options[Aggregator] (only). \nFirst, NumberOfFactors is updated. When NumberOfFactors -> Automatic then the setting is not changed.\nThen the options Factors, FactorCoefficients and FactorPrices are set to the length given by NumberOfFactors. Canonic inner terms are FactorX, FactorC and FactorP. Similarly, additional ResetFactors -> ... are taken and set.\nIf Clear -> True, then the Factor terms are Cleared and thus get their canonic value. If Clear -> False, then they keep their value. If Clear -> Automatic (default), and NumberOfFactors -> Automatic (default), then you are prompted whether you want to Clear Factors. (Thus when NumberOfFactors -> number, then you will not be prompted, and with setting Clear -> Automatic the Factors will not be Cleared.)\nFinally, the option Factor is found by FactorPosition (and similarly Cleared)."

Rate::usage = "Keyword"
Revenue::usage = "Keyword"

ResetFactorsExpand::usage = "ResetFactorsExpand[n] takes ResetFactors -> facs of Options[Aggregator], and facs = {{xi, yi}, ...} becomes {xi -> Array[yi, n], ...}"

Results$Aggregator = SequenceToRules[Sort[{Aggregator, Function, Cost, Profit, MinimalCost, MaximalProfit,}], Null];

Function::usage = Key[AddedUsage, Function, "1)Keyword for option DemandFunction -> Function. The factor demand is taken at the efficiency frontier, given the other inputs and disregarding other optimality conditions.\n2) Keyword in Results[current_aggregator] to store the actual definition of the function."]

RateOfInterest::usage = "Keyword for the rate of interest. A perunage and not a percentage"

RTS::usage = "A label for Returns to Scale, typically as Return -> RTS. By default, however, Return -> 1, while RTS has no value."

SetFunction::usage = "SetFunction allows the simultaneous setting of local names and default numerical values for parameters, by the form of Key -> localname -> defaultvalue. Input: SetFunction[opts] with default aggregator or SetFunction[f, opts]. Output: {Function -> f[g[opts]], CoefficientList -> h[opts], Factors -> ...}, where g and h are functions dependent upon f. For example\n   SetFunction[CES, Ces -> S -> .4,  ...] gives\n   {Function -> CES[Ces -> S, ... ], CoefficientList -> {S -> .4, ....}, Factors -> ...}."


Turnover::usage = "Turnover[d, a, p:1] for total demand d, average inventory a and period p. Note that turnover is an 'average' concept"

UnitCost::usage = "Keyword"

UnitFactorCoefficientsQ::usage = "UnitFactorCoefficientsQ[opts___Rule] takes the FactorCoefficients of the current aggregator (in opts or taken from Options[Aggregator]) and tests whether they add to 1. If the coefficients are symbolic, then output is the rule that they should add to 1."


Capacity::usage = "Keyword"

Utilisation::usage = "Keyword"

ValueAdded::usage = "Keyword for Production - Intermediate"
Wealth::usage = "Keyword. The budget situation has a sink and a flow"


Begin["`Private`"]
End[]
EndPackage[]
Print["This is a crippled package: it contains only the usage statements, no routines. Use of the proper software requires a user license.
See http://www.can.nl/~cool or write to Thomas Cool, Rotterdamsestraat 69, NL-2586 GH Scheveningen, Holland for ordering details"]
