(*********************************************************************

	Cool`Graphics`  package


 *********************************************************************)



(* :Author: Thomas Cool *)
(* :Copyright: Copyright 1996 Thomas Cool *)
(* :Package Version: 2.07,  August1998.*)
(* :Mathematica Version: 3.0 *)
(* :Keywords:    *)
(* :Limitation: *)
(* :Acknowledgement: the idea of a plot in the {x, x+1} space is from Eckalbar, in Varian (1993), "Economic and financial modeling with Mathematica", Telos *)
(* :License: use of this file requires a license, usually available
      by payment of $10 to Swift account ING.B.NL.2A 3736767 to the name of 
      Thomas Cool, Rotterdamsestraat 69, 2586 GH Scheveningen, Holland.
      Please inquire about the cost of packs. See the License[] function. *)

Needs["Cool`Common`"]

BeginPackage["Cool`Graphics`", Join[{}, $Cool]]

Arcs::usage = "Arcs[c, f, g] gives a graphics primitive of two arcs with the angle made from center c = {cx, cy} and legs towards f = {fx, fy} and g = {gx, gy}. Results[Arcs] gives the size of that angle"

Asymptot::usage = "Asymptot[{x, y}, direction (, options)]\n is a graphics object\n if direction = True then the asymptot is vertical \n if direction is False then the asymptot is horizontal \n if direction = Automatic then both \n the default option is DashingValues -> {.02, .02}"

Options[Asymptot] = {DashingValues -> {.02, .02}}

AsymptotAt::usage = "AsymptotAt[y_, left_, position_] if one wants to plot a vertical line at position, the size of left requires trial and error"

BlockGP::usage = "BlockGP[w, h, a, c] gives a graphics primitive of a 'block', with width w, height h, angle with the horizontal axis of a (default 0), and the top centered at c, default {0,0}"

DashedCircle::usage = "Graphics objects: \nDashedCircle[c, r, {th1, th2}] gives a dashed circle arc with center c, radius r, for angle th1 till th2.\nDashedCircle[x_List, c_:{0, 0}] with x a list of pairs {pi, qi}, gives the dashed circle arcs with center c through those points"

DashingValues::usage = "Option of Asymptot"

DisplayFunctionFilter::usage = "DisplayFunctionFilter[{opts___Rule}, ownopts___Rule] creates a pair {r, s}, where:\ns is {opts} with all DisplayFunction option statements deleted\nr is a DisplayOption -> value statement, either selected from opts, or at a default setting controlled by Options[DisplayFunction] or ownopts"

EqualProductContour::usage = "EqualProductContour[x_List, opts___Rule] for x a list of pairs {pi, qi} (prices and quantities) gives the contours of equal products (values) vi = pi * qi.\nThere are two server subroutines:\nEqualProductContour[1, {p, q}, {min, max}, opts___Rule] gives a single contour graphics object for point {p, q} for the min to max range of p  (with property DisplayFunction -> Identity).\nEqualProductContour[2, x_List, opts___Rule] gives a list of contour graphics objects.\nGeneral Graphics options apply."

EqualSumContour::usage = "EqualSumContour[x_List, opts___Rule] for x a list of pairs {pi, qi} (Log of prices and quantities) gives the contours of equal sums (values) Log[vi] = Log[pi * qi] = Log[pi] + Log[qi].\nThere are two server subroutines:\nEqualSumContour[1, {p, q}, {min, max}, opts___Rule] gives a single contour graphics object for point {p, q} for the min to max range of p (with property DisplayFunction -> Identity).\nEqualSumContour[2, x_List, opts___Rule] gives a list of contour graphics objects .\n\nEqualSumContour[x_List, y_List, opts___Rule] gives a single contour based on the minima and maxima in x and y, where x and y can have arbitrary equal length.\nGeneral Graphics options apply."

EqualValueContour::usage = "EqualValueContour[p_List, q_List, number, type] gives a graphics object with property DisplayFunction -> Identity, for 1 or All equal value contours of either v = p + q or v = p*q. Only known values are number = {1, All}, type = {Plus, Times}"

LineRasterGP::usage = "LineRasterGP[xs_List, ys_List,{bx, ex}, {by, ey}] 
gives a graphics primitive of a raster of lines at x's and y's positions, within the rectangular area determined by begin and end values {bx, ex}, {by, ey}"
	
ListDensityPlotSquared::usage = "ListDensityPlotSquared[x_] partitions x into a square matrix and makes a density plot"

LP2DPlot::usage = "LP2DPlot[c_List, m_List, b_List, opts___Rule] calls 
LinearProgramming[c, m, b], stores the results in Results[LP2DPlot], and makes a 2D plot of the restrictions and solution. The solution is graphically identified by a dashed ray from the origin. The routine works only for 2D problems (m has 2 columns). Options are past on to Plot.\nNote: 
LinearProgramming essentially minimises. A maximising problem of max c.x 
subject to m.x <= b and x >= 0 can be entered as LinearProgramming[-c, -m, -b], and the same can be done for LP2DPlot. Be aware, though, that the maximal value found still is c.x and not -c.x\nNote: The automatic plotting range is from 0 till some implied maximum value, which may be infinite when there are zero matrix elements. Use the standard option PlotRange to control the plot range"

Parallelogram::usage = "Parallelogram[a, b, c, opts___Rule] is a graphics primitive of a parallelogram through the three points. If option Arcs -> True (default False), then the angle at a is 'arced'. Use as Show[Graphics[Parallelogram[...]]]"

ParametricRange::usage = "ParametricRange[{fx_, fy_}, t_, xrange_, yrange_] gives the {t, tmin, tmax} range for the t variable in the ParametricPlot[{fx, fy}, {t, tmin, tmax}], with given ranges for the x and y axes."

PhaseDiagram::usage = "PhaseDiagram[x_List, t_:True, opts] gives a phase diagram for a list x. The routine XXPlusSpace is used to project x in the {x[[i]], x[[i+1]]} space. Note that this result is stored in Results[XXPlusSpace, t]. The resulting array is plotted, in black or red. Options for t are True, False or All."

PlotLine::usage = "PlotLine[x_List, opts___Rule] is ListPlot with PlotJoined -> True\nPlotLine[x_List, y_List, opts___Rule] idem for two variables, now with application of Pick, DataFilter and Transpose"

Rainbow::usage = "Rainbow shows hues and Hue numbers, valid from 0 till 1"

Triangle::usage = "Triangle[a, b, c, opts] is a graphics primitive of a triangle of the three points. If option Arcs -> True, then the angle at a is 'arced'. When displaying, use Show[Graphics[Triangle[...]], AspectRatio -> Automatic] to get a proper print"

UtilisationContours::usage = "UtilisationContours[f o/c, {c, cmin, cmax}, {o, omin, omax}, opts] with\n   u = f o/c = utilisation degree\n   c = capacity\n   o = output\n   f = unit adaptation, when c and o are measured differently. For example, when c is measured in units per day and o in 1000 units per year, then f = 1000 / 365.\nThe options are passed on to ContourPlot"

Begin["`Private`"]
End[]
EndPackage[]
Print["This is a crippled package: it contains only the usage statements, no routines. Use of the proper software requires a user license.
See http://www.can.nl/~cool or write to Thomas Cool, Rotterdamsestraat 69, NL-2586 GH Scheveningen, Holland for ordering details"]
