(******************************************************************

	Cool`Lagrange`  package


 ******************************************************************)



(* :Author: Thomas Cool *)
(* :Copyright: Copyright 1995 Thomas Cool *)
(* :Package Version: 1.03, July 1995.*)
(* :Mathematica Version: 2.2.2 *)
(* :Keywords:    *)
(* :Limitation: no second order implemented *)
(*Acknowledgement: 
1) Though the Lagrange method is very useful and common in optimalisation (and economics), the inspiration for the present implementation comes from C. Henry Edwards, "Ladders, Moats, and Lagrange Multipliers", The Mathematica Journal, Winter 1994 pp 48-52. I've concentrated on the user-friendly option interface.
2) MyFindRoot comes from the Varian book, see there. The package name has been
adapted to the context name.*)
(* :License: use of this software file requires a license, usually available
      by payment of $10 to Swift account ING.B.NL.2A 3736767 to the name of 
      Thomas Cool, Rotterdamsestraat 69, 2586 GH Scheveningen, Holland.
      Please inquire about the cost of file packs. See the License[] function. *)

Needs["Cool`Common`"]

BeginPackage["Cool`Lagrange`", Join[{"MyFindRoot`"}, $Cool]]


Options$Lagrange::usage = "Start up values for ResetOptions";

Options$Lagrange := Sort[{NumberOfVariables -> 0,  NumberOfConstraints -> 0, 
		Multipliers ->{}, MultiplierSymbol -> Mu,  MultiplierEquations -> {}, 
		Constraints -> {}, Expression -> Null, Variables -> {}, StartValues -> {},
		MultiplierStartValues -> {}, Out -> {}, Condition -> First, 
		Routine -> FindRoot, RealRootQ -> False}];

Options[Lagrange] = Options$Lagrange;

Lagrange::usage = "Solving for an optimum of scalar f[x] subject to array g[x] == 0.
You can use Solve, or FindRoot with initial values x0, or, in principle, your own routine.\n1)Lagrange[opts___Rule] with for example Expression -> f, Variables -> x, Constraints -> g, Routine -> ...  (, StartValues -> x0); or \n2) Lagrange[f_, g_, x_, x0_List:{}, mu_Symbol:Mu]\nOutput contains Lagrange multipliers m and has the form:\n   for FindRoot: {f[x*], {x -> x*}, {m -> m*}}, \n   for Solve: {f[yi*], {yi -> yi*}} for i solutions, where y can be x and m intermixed.\nDefaults are taken from Options[Lagrange], and output is also put there. (Options are cleared by ResetOptions[Lagrange].) Additional inputs (with defaults) are: MultiplierSymbol -> Mu, RealRootQ -> False (include Complex results of Solve), Routine -> FindRoot (see ?Routine), Condition -> (Min, Max or First (only first order conditions: default)).  Additional outputs are: NumberOfVariables -> ..., NumberOfConstraints -> ..., Multipliers -> {...}, MultiplierEquations -> {D[f + mg, x] == 0}, MultiplierStartValues -> {m0, found by least squares on x0}, Out -> {format given above}.\nInput options relevant for the routine are passed on to the routine.";

MultiplierEquations::usage = "1)input MultiplierEquations[opts___Rule] or \n2)input MultiplierEquations[f_, g_, x_, mu_Symbol:Mu]\n1 & 2) update Options[Lagrange] \n3)output MultiplierEquations -> {D[f + mg, x] == 0} in Options[Lagrange]. These equations are also used to find the starting values m0 of the Lagrange multipliers when Routine -> {rout, FindRoot}.";

MultiplierStartValues::usage = "MultiplierStartValues[f_, g_, x_, x0_] subroutine of Lagrange, finds the starting value m0 of the Lagrange multipliers using least squares on MultiplierEquations.";

Expression::usage = Key[AddedUsage, Expression, "Input option for the expression on which the procedure operates."];
Variables::usage = Key[AddedUsage, Variables, "Input option giving the list of symbolic names of the variables."];
Condition::usage = Key[AddedUsage, Condition, "Input option, values First (first order condition only), Min or Max (kind of second order)."];
Out::usage = Key[AddedUsage, Out, "Output option keyword, giving the result of the latest call."];
StartValues::usage = Key[AddedUsage, StartValues,"See Lagrange"];

Routines::usage = "List of known routines, now {Solve, FindRoot, MyFindRoot}";

Routine::usage =  "1) Lagrange[..., Routine -> routi,...]\n2) Lagrange[..., Routine -> {routj, routi},...] \n both call Lagrange[routi, ...], where routi first is a format and secondly might be an actual routine. Thus, when routj uses the input format of a known routine (and the format only), then give Routine -> {routj, knownroutine}. See ?Routines for the known routines (formats). You might append your own routine. MyFindRoot is an example.";

MultiplierSymbol::usage = "Keyword, see Lagrange";
Multipliers::usage = "Keyword, see Lagrange";
Constraints::usage = "Keyword, see Lagrange";
NumberOfVariables::usage = "Keyword, see Lagrange";
NumberOfConstraints::usage = "Keyword, see Lagrange";

Begin["`Private`"]
End[]
EndPackage[]
Print["This is a crippled package: it contains only the usage statements, no routines. Use of the proper software requires a user license.
See http://www.can.nl/~cool or write to Thomas Cool, Rotterdamsestraat 69, NL-2586 GH Scheveningen, Holland for ordering details"]
