(*********************************************************************

	Cool`Logic`  package


 *********************************************************************)



(* :Author: Thomas Cool *)
(* :Copyright: Copyright 1994/97 Thomas Cool *)
(* :Package Version: 2.02 Thomas Cool, July 1997 *)
(* :Mathematica Version: 3.0 *)
(* :Keywords:   Propositional Logic, Decision Analysis, Education  *)
(* :Limitation:  Of course. E.g. pattern matching in AndOrRules and AndOrEnhance[] is not extensively tested.*)
(* :License: use of this software file requires a license usually available
      by payment of $10 to Swift account ING.B.NL.2A 3736767 to the name of 
      Thomas Cool, Rotterdamsestraat 69, 2586 GH Scheveningen, Holland.
      Please inquire about the cost of file packs. *)

Needs["Cool`Common`"]

BeginPackage["Cool`Logic`", Join[{}, $Cool]]

Analyse::usage = "Analyse[sentence] and subroutines Analyse[If || And || Or, sentence] \n transform sentence (a String of Standard Sentence Format) into a Mathematica Format"

AnalysePrint::usage = "AnalysePrint[x_ (, props_)] prints the original statement x, may set the propositional analysis in props, and gives the PropositionMeaningRule"

AndOrEnhance::usage = "AndOrEnhance[x] with x = True or False, default True\n allows an enhanced use of && and ||,\nwhich e.g. makes  p && Not[p]  -> False"

AndOrEnhanced::usage = "AndOrEnhanced: gives the state of the system"

AndOrRules::usage = "In standard Mathematica, these can be used (and extended on) as rules that enhance And & Or.\nIn AndOrEnhanced mode, these rules are added to the definition of And & Or. Note that the rule then cannot be used."

ATOP::usage = "ATOP = {And -> Times, Or -> Plus}"



Choose::usage = "Choose[x_List, val_:True] := Map[ (# -> val)& , x]"

ChooseP::usage = "ChooseP[x_List, val_:True] := Map[ (P[#] -> val)& , x]"

ChoosePrint::usage = "ChoosePrint[x_List, rule_, val_:True] := (Print[Map[P, x]  /. rule ]; Map[ (P[#] -> val)& , x] )"

Conclusions::usage = "Contains the list of conclusions currently accepted.\nIf you start a new round, either give Conclusions = {} or Conclude[]"

Conclude::usage = "Conclude[x] gives the new conclusions in x, i.e. those that are not already in Conclusions.\n Conclude[] is equal to Conclusions = {},\nand you will want to do this at a new round of deductions."

Decide::usage = "Decide[x, opts] := Conclude[Deduce[Conclude[x], opts]] may decide issues\nThe procedure automatically turns on Enhanced use of And & Or"

Options[Deduce] = {PropVariableList :> Propositions, Deduce -> LogicalExpand}

Deduce::usage = "Deduce[statement_String, opts___Rule] first transforms a simple English text into a List of Mathematica Expressions in propositional logic. It generates the current values of Propositions and PropositionMeaningRule. \nDefault Option is PropVariableList -> Propositions, so that Deduce recognises only P[i] statements. If the original statements are not in text form, then the user must supply a variable list.\nAs a second step, the method of deduction is applied. Options[Deduce, Deduce -> LogicalExpand] is default, but another setting is Implications"

Equivalent::usage = "Equivalent[p, q] means (p => q) && (q => p)"

FromEquationRule::usage = "FromEquationRule[var_List] gives the rules for transforming equational forms back into propositional logic"

ToDNForm::usage = "ToDNForm[expr] changes expr into the disjunctive normal form, by substituting If, Implies and Equivalent by And, Or & Not"

Imp::usage = "Rule -> Implies\nExample: p -> (p -> q) /. Imp\nThe use of Imp allows the use of the Rule-symbol -> for logical input readability"

RemarkOnParentheses::usage = "Mathematica does generally not print parentheses around And, Or, and Implies. For example, in Mathematica 3.0 the precedence order printout of Implies in Traditional Form actually is erroneous: (p => (q => r)) is printed the same as ((p => q) => r), both without parentheses. The Logic` package inserts parentheses if you print in TraditionalForm"

Implications::usage = "Implications[x] give a list of implications of x. If joined by And, then all implications are equivalent to the original"

JoinStatements::usage = "JoinStatements[x_List] concatenates statements while inserting a Blank inbetween"

LocateThen::usage = "LocateThen[listif_, listthen_] \nsubroutine for Analyse[If, _] determines which 'then' belong to the first 'if'"

LogicLab::usage = "LogicLab[r,x] or LogicLab[{r,x}]\nIf r is a List and x not, then all rules are applied simultaneously.\nIf r is a List and x too, then the procedure does Map[LogicLab[r, #]&, x].\nIf  LogicLab[{r_List, x_List}]  then Outer\nHence, to apply separate rules in r on a single x, input LogicLab[{r, {x}}].\nLogicLab gives:\n-> in print form: the input statement x, y = LogicalExpand[x], z = y //. r, the truthtable result\n-> in output: the collection of truthtable results"

LogicalVariables::usage = "LogicalVariables[x] provides the list of variables for a logical statement x."

Negate::usage = "Negate[x_] := LogicalExpand[ !x ]"

NotNot::usage = "NotNot[x_] := !Negate[x] := !LogicalExpand[ !x ]"

NotpOrq::usage = "NotpOrq[p, q] := Not[p] || q\nThis function is used to replace If[p, q] and Implies[p, q]"



ProperSentence::usage = "ProperSentence[x_String] \nchanges x into a proper sentence, meaning that it is in LowerCase and starts with a Blank"

P::usage = "P[i] is an atomic sentence, the ith element in Propositions. \nEnter P[i] /. PropositionMeaningRule to substitute the various meanings."

Paragraph::usage = "Advised for storage of results from translating proper texts into \"Englogish\" and applying logical analysis. A proper text is divided into labelled paragraphs, these are deduced separately, and the results are then combined. Due to computing time, Deduce is not called for the combined text.\n\nParagraph[Label] contains the list of labels.\nParagraph[Set] sets the list of labels to {}.\nParagraph[label, \"...\"] associates the label with the input text and updates the list of labels.\nParagraph[Set, In, All] joins the input texts associated with the list of labels.\nParagraph[In, label] contains the associated text. (Label = All gives the joined text, when first Set).\n\nParagraph[Set, Out, head, label (, opts)] applies head with opts to Paragraph[In, label] (e.g. head = Deduce or AnalysePrint). The result is put into Paragraph[Out, head, label].\nParagraph[Set, Deduce, label (, opts)] does the former for Deduce but then applies the current PropositionMeaningRule. \nParagraph[Out, head, label] is used to store results of Paragraph[Set, Out, head, label]. (Label = All for the joined text.)\n\nParagraph[Deduce, All, done_:True (, opts)] could follow after a number of Paragraph[label, ...] statements. If done is False, it calls Deduce on the paragraphs (with the opts). It fills Paragraph[Out, Deduce, All] as a conjunction of Deduce on the separate paragraphs (without calling Deduce for the whole)."

Propositions::usage = "Propositions is the list of atomic sentences P[i]. \nEnter Propositions /. PropositionMeaningRule to substitute the various meanings."

PropositionMeaningRule::usage = "This is a rule that gives the meaning of the current atomic sentences."

ToAlgebra::usage = "ToAlgebra[x] translates an expression x into an algebraic equality statement, by replacing And -> Times, Or[p,q] -> 1 - (1-p)(1-q), Not[p] -> 1 - p. If the option All -> True is set, then included are equalities p == 1 || p == 0, so that the output can be offered to Reduce"

PropVariableList::usage = "PropVariableList is an option for Deduce; default is PropVariableList -> Propositions"

Sentences::usage = "Sentences[Statement_String]\n Transforms a statement into a List of Proper Sentences. A statement is a String that contains English sentences that start with a (Blank &) Capital Letter and that end with a Point (& Blank). This present text is a very example of a statement." 

TertiumNonDatur::usage = "TertiumNonDatur[x_]  :=  (x || Not[x])"

ToEquationRule::usage = "ToEquationRule[var_List] gives the rules for transforming propositions into equational forms"

ToLogic::usage = "ToLogic[Kind_, input_, parms_] \n uses standard routines Kind  (e.g. Collect, Expand etcetera) by exploiting the structural Equivalent of {And, Or} with {Times, Plus}. \nThe routine in fact does:\nKind[input  /. {And -> Times, Or -> Plus}, parms]  /. {Times -> And, Plus -> Or}"

ToPropositionalLogic::usage = "ToPropositionalLogic[statement_String] \nTransforms an 'English' statement into a List of Mathematica Logical Expressions. The result can be submitted to Deduce[...]. The routine also generates in the Global context the Propositions = {P[1], ... } that is the default PropVariableList in Deduce. Also generated is PropositionMeaningRule that allows to replace the P[i] by the relevant original substatements."

TruthTableRule::usage = "TruthTableRule[x_:Propositions] \n gives a truth table result.\nIf x is a List of (logical) variables, then a replacement Rule is created. \nIf x is a statement, then the statement is evaluated with that Rule, which gives only the evaluation result."

TruthValue::usage = "TruthValue[x] gives the truth share from 0 to 1.\n A tautology means 1, a contradiction means 0."

TruthTable::usage = "TruthTable[x] gives a list of rules in the various combinations of {p, q, ...} -> True / False. \nOptions can only be given by SetOptions[TruthTable, ...]. Default option is Rule -> Implies, meaning that '->' in input is read as 'implies'. Other values disable this option. Options[TruthTable] also applies to Decide, TruthValue, TruthTableRule and LogicalVariables."

Begin["`Private`"]
End[]
EndPackage[]
Print["This is a crippled package: it contains only the usage statements, no routines. Use of the proper software requires a user license.
See http://www.can.nl/~cool or write to Thomas Cool, Rotterdamsestraat 69, NL-2586 GH Scheveningen, Holland for ordering details"]
