(*********************************************************************

	Cool`Model`  package


 *********************************************************************)



(* :Author: Thomas Cool *)
(* :Copyright: Copyright 1996/98 Thomas Cool *)
(* :Package Version: 1.02,  July 1998*)
(* :Mathematica Version: 3.0.0 *)
(* :Keywords:   Econometrics, Model, Solve, Time Series *)
(* :Limitation: *)
(* :License: use of this software file requires a license usually available
      by payment of $10 to Swift account ING.B.NL.2A 3736767 to the name of 
      Thomas Cool, Rotterdamsestraat 69, 2586 GH Scheveningen, Holland.
      Please inquire about the cost of packs. See the License[] function. *)

Needs["Cool`Common`"]


BeginPackage["Cool`Model`", Join[{"Cool`Lags`", "Cool`Data`"}, $Cool]]

Unprotect[$Endogenes, $Exogenes]

$Endogenes::usage = "Option keyword that regulates the input format.\nIf $Endogenes -> Automatic (default), then Model[...] can find the endogenes in the equations itself. They are identified as those variates that do not have a time indicator. Thus one defines equations like y == .... By consequence, current period exogenes have to be indicated by a time indicator, like x[t]. This is called the model-canonical form.\nIf $Endogenes -> {y1, y2, ...} then the list of endogenes is given, and the other variates apparently are the exogenes. In that case, one can define equations like y[t] == ...\nWhat format one chooses depends upon legibility and variability of the model specification. A more fixed model can be more legible if one drops the [t] parts; while in a model where one varies the exogenes, it may be easier to adjust $Endogenes rather than adding and dropping those [t] parts."

$Exogenes::usage = "Option keyword, output of Results[Model]. See $Endogenes."

Begin::usage = Key[AddedUsage, Begin, "Keyword for the StartYear of the data."]

Coefficients::usage = Key[AddedUsage, Coefficients, "This is such a complex situation. Last example is used in the internal workings of Model[]"];

Endogenes::usage = "A list of Symbols used for the endogenes in the model, i.e. those variables that one wishes to solve the model for.";

EndogenesRule::usage = "EndogenesRule[] gives a rule so that one can switch from the non-model-canonical form to the model-canonical form. See Back." 

Equations::usage = Key[AddedUsage, Equations, "Equations[t_] := { ... == ..., ...} gives a list of equations, where the Endogenes must be without time index t, while the Lagged and the Exogenes are with such a time index. For example:\n   {..., y == y[t-1] + a x[t] + z[t-2], ... } "];

Exogenes::usage = "A list of Symbols used for the exogenes in the model (other variates than the endogenes).";

LongestLag::usage = "LongestLag can be used when Equations[t_] have been defined"

Options$Model = {SetData -> {}, Equations -> {}, Begin -> 1, 
	Coefficients -> {}, $Endogenes -> Automatic} // Sort;

Options[Model] = Options$Model

Model::usage = "Model[Rules] or Model[{Rules}, opts___Rule] sets up Equations[t_], finds the Endogenes and Exogenes in the Equations, and fills the Data. The rules are to be given in the same format as in Options[Model], while defaults are taken from there. $Endogenes controls whether the Endogenes are found automatically or not."

NSolveYear::usage = "NSolveYear[t_] selects the first solution to define endogenous values {y1[t], ... }. Note: this does not check on StartYear, as NSolvePeriod does.";

Options[NSolvePeriod] = {End -> True}

NSolvePeriod::usage = "NSolvePeriod[t (, s), opts] calls NSolveYear for the given period, default s = StartYear + LongestLag. The minimum of {t, s} is taken as the beginning of the period, the maximum as the end.\nIf the option is set to End -> True (default) then the end is bounded by the minimum length of all exogenes. Note that this is a restriction, if not all exogenes have the same length, and one wishes to vary the model specification.";

Solution::usage = "Solution[t] contains the full solution for year t";

ModelVariates::usage = "ModelVariates[Equations] determines the Endogenes and the Exogenes from the Equations. The model-canonical form is used, see $Endogenes.\nModelVariates[] simply joins the existing sets.";

HowToModelQ::usage = "Either use Model[...] to define the model, or use these various steps:\n   Equations[t_] := {...}\n   Endogenes = {...}\n   Exogenes = {...}\n   StartYear = ...\n   SetData[{...}]\nThen you call NSolveYear[...] or NSolvePeriod[...].\nUse Symbols for the Variates.\nCheck on the proper input formats by using ?Command."

Store::usage = Key[AddedUsage, Store, "Store[label] puts the current values of the Endogenes into Data[x, label]"]

Timing::usage = Key[AddedUsage, Timing, "This time indicator is also used in the Equations option of Model[...]"]

TimeZone::usage = Key[AddedUsage, TimeZone, "Output option of Results[Model], gives the maximal simulation period, counting the maximal lag in the model and the available data."]

Begin["`Private`"]
End[]
EndPackage[]
Print["This is a crippled package: it contains only the usage statements, no routines. Use of the proper software requires a user license.
See http://www.can.nl/~cool or write to Thomas Cool, Rotterdamsestraat 69, NL-2586 GH Scheveningen, Holland for ordering details"]
