(*******************************************

	Cool`Operations`  package


 *******************************************)



(* :Author: Thomas Cool *)
(* :Copyright: Copyright 1997 Thomas Cool *)
(* :Package Version: 1.05,  July 1998.*)
(* :Mathematica Version: 3.0.0 *)
(* :Keywords:    *)
(* :Limitation: *)
(* :License: use of this software file requires a license usually available
      by payment of $10 to Swift account ING.B.NL.2A 3736767 to the name of 
      Thomas Cool, Rotterdamsestraat 69, 2586 GH Scheveningen, Holland.
      Please inquire about the cost of packs. See the License[] function.
 *)

Needs["Cool`Common`"]

BeginPackage["Cool`Operations`", Join[{"Cool`LP`", "Cool`Decision`", "Cool`Economic`Common`", "Cool`Statistics`Common`", 
"Statistics`DescriptiveStatistics`"}, $Cool]]

Backorder::usage = "Keyword"

EOQ::usage = "EOQ[d, c, s] gives the economic order quantity, for:\n
d = demand\n
c = cost per order\n
s = stock costs per unit\n
Details can be found in Results[EOQ]\n\n
EOQ[Plot, d, c, s, {qmin, qmax}] gives a plot of the order and storage costs, for given range\n\n
Note: the formula is attributed to Harris 1913 or Camp 1929\n\n
EOQ[d, c, s, bc] gives the order quantity when backorders are allowed with per time unit cost bc. If bc -> Infinity, then this model becomes the EOQ."

EBQ::usage = "EBQ[d, c, s, r] gives the economic batch quantity when the commodity is not ordered but produced. The demand speed is r times the production speed, normally 0 < r < 1. Note that the EBQ = EOQ[d, c, s (1 - r)]. Details can be found in Results[EBQ]"

GanttChart::usage = "GanttChart[data_List, opts] gives a Gantt Chart of 
activities on various machines (rows) for periods (columns). The data consist of lists of recipes. A recipe = {productlabel, machinei, {begini, endi}, machinej, {beginj, endj}, ...}. The productlabel cannot be a number, and preferably is a string so that warnings are issued when recipes overlap. The machine labels must be integers. One may leave out machines if these are not used, so that the recipes are of different length. The machines can also be mentioned in arbirtrary order, though one might prefer the time sequence of the activities. The default output is a graphics plot, and in that case it is possible to choose the beginning of an activity as equal to the end of the former activity; and these values can be non-integer. For example: {A, 1, {0, 1}, 2, {1, 3}}\nGanttChart[Table, data_List] gives a tabular representation. In that case the beginnings and endings of activities must be nonnegative integers, and they may not be equal. For example: {A, 1, {1, 1}, 2, {2, 3}}\nUse GanttChart[TableForm, data_List, h:1] to change plot data into data suitable for tables, and GanttChart[Plot, data_List, h:1] to change tabular data into data suitable for plotting. The change involves adding or substracting h units (default 1) to or from the x-axis co-ordinates"


IndependentDemandInventory::usage = "IndependentDemandInventory[EOQ, {d, c, 
s}, Normal, {mu, sigma}, OLT, level:.95] uses Order Lead Time OLT and the 
cycle service level to find:\n   (1) e = EOQ[d, c, s];\n   (2) the P-system 
with TargetInventory using the Time Between Orders TBO = Floor[e / mu];\n   (3) the Q-system with the ReOrderPoint.\nNote: sigma is measured for the 
periodic demand mu, for d / mu periods. The inconsistency of fixed total 
demand d and probabilistic periodic demand is overlooked" 

MaxInventory::usage = "Keyword"


NumberOfOrders::usage = "Keyword"

NewsBoyProblem::usage = "NewsBoyProblem[p, c, u, o, {pm_List, states_List}] 
gives the minimal expected loss strategy for a newsboy, who has to buy q newspapers at cost c per paper, and who sells at price p per paper under uncertain demand states that have a discrete probability measure pm. Additional unit costs are o for overcapacity (demand < q) and u for undercapacity (demand > q). The payoff table is defined as in Cool`Decision` as profits for nature, so negative values are positive income for the newsboy.\nNewsBoyProblem[Set, p, c, u, o] sets the Options{Aggregator] for this problem. See Profit[] and Cost[]"


InventoryPolicyCost::usage = "InventoryPolicyCost[n, c, a, s] provides the sum of\nOrderCost = n c, for c = cost per order, n = number of orders, and\nStorageCost = a s, for s = stock costs per unit average stock, a = average stock"

JohnsonsRule::usage = "JohnsonsRule[Sort, ps] reorders ps into the best 
schedule, where ps is a list of pairs {{t1, t2}, ...}. Assumed is that: (a) 
All products are to be handled first on machine 1 and then on machine 2. (b) For product i, the pair {t1i, t2i} gives the time t1i on machine 1 and the time t2i on machine. Output is the reordered list of pairs. Results[
JohnsonsRule, Order] contains the permutation\na = JohnsonsRule[ps_List, labs_List] produces the data that can be put into GanttChart[a]\nb = JohnsonsRule[Table, ps_List, labs_List] produces the data that can be put into GanttChart[Table, b]\nIn both cases, labs is a list of labels for the products or production processes (preferably strings). Results[
JohnsonsRule, MakeSpan] gives the logistics results"

OrderQuantity::usage = "Keyword"

OrderCost::usage = "Keyword in EOQ: the total costs incurred by ordering"
StorageCost::usage = "Keyword in EOQ: the total costs incurred by storage"

OrderLeadTime::usage = "Keyword. The  OLT is the time required for an order to materialize in the arrival of the products"

ReOrderPoint::usage = "ReOrderPoint[Normal, {mu, sigma}, OLT, cycle 
service level:.95] determines the ROP of a continuous (Q) inventory control system, using the Normal distribution with average demand mu (per unit of time), spread sigma (per unit of time), the Order Lead Time OLT (in units of time), and the cycle service level (default 95%). The Results[ReOrderPoint] give the average demand and the safety stock"

ReOrderPointCycle::usage = "ReOrderPointCycle[demand, period, order quantity (e.g. EOQ), reorderpoint, cost per order:0, cost per unit of average storage:0]  give the cycle key data"

SafetyStock::usage = "Keyword"

TargetInventory::usage = "TargetInventory[Normal, {mu, sigma}, TBO, OLT, cycle service level:.95] determines the TIL of a periodic (P) inventory control system, using the Normal distribution with average demand mu (per unit of time), spread sigma (per unit of time), the Time Between Orders TBO and the Order Lead Time OLT (in units of time), and the cycle service level (default 95%). The Results[TargetInventory] give the average demand during TBO + OLT and the safety stock"

TargetInventoryCycle::usage = "TargetInventoryCycle[demand, period, target inventory, time between orders, cost per order:0, cost per unit of average storage:0] gives the cycle key data"

TimeBetweenOrders::usage = "Time between orders TBO. For the EOQ: TBO = order lot size / total demand. In this case the order lot size equals the average demand during the TBO"

MakeSpan::usage = "Keyword. The makespan of a list of activities is the total time by which they are all completed. A common objective is to have minimal makespan"

JobFlowTime::usage = "Keyword. The job flow time is the cumulative time from beginning to the end of an activity, including waiting e.g. as 'work in progress' but excluding 'waiting as finished product'. When averaging over more activities, it is presumed that time measurement starts at the same moment for all, so that many activities may start with waiting. Then: WorkInProgress[Average] = JobFlowTime[Average] * NumberOfActivities / MakeSpan"

PrDemandLessThanLevel::usage = "PrDemandLessThanLevel[unitCostOfUndercapacity, unitCostOfOvercapacity] gives the probability P = Pr[q < Q] that demand is less than the optimal capacity level Q, as a function of the unit losses of undercapacity and overcapacity. The optimal capacity level Q then can be determined by setting the cumulative demand probability equal to this probability. Thus Solve[P == Cum[Q], Q]\n\nPrDemandLessThanLevel[under, over, Constant, {min, max}] gives the {P, Q} values for the uniform distribution over the {min, max} range, and \nPrDemandLessThanLevel[under, over, Normal, {
mu, sigma}] gives the {P, Q} values for the normal distribution\nPrDemandLessThanLevel[under, over, PM, {pr_List, st_List}] gives the {P, Q} values for a discrete probability measure pr over states st; note though that NewsBoyProblem[] here gives a more robust result"

WorkInProgress::usage = "Keyword. The inventory that consists of products that are still in production"

Begin["`Private`"]
End[]
EndPackage[]
Print["This is a crippled package: it contains only the usage statements, no routines. Use of the proper software requires a user license.
See http://www.can.nl/~cool or write to Thomas Cool, Rotterdamsestraat 69, NL-2586 GH Scheveningen, Holland for ordering details"]
