(*******************************************

	Cool`Physics`  package


 *******************************************)



(* :Author: Thomas Cool *)
(* :Copyright: Copyright 1997 Thomas Cool *)
(* :Package Version: 1.11,  July 1998.*)
(* :Mathematica Version: 3.0 *)
(* :Keywords:    *)
(* :Limitation: *)
(* :License: use of this software requires a license, usually available
      by payment of $10 to Swift account ING.B.NL.2A 3736767 to the name of 
      Thomas Cool, Rotterdamsestraat 69, 2586 GH Scheveningen, Holland.
      Please inquire about the cost of packs. See the License[] function.
 *)

Needs["Cool`Common`"]

BeginPackage["Cool`Physics`", Join[{"Cool`Arrowise`", 
"Graphics`Arrow`", "Miscellaneous`PhysicalConstants`", "Miscellaneous`Units`", 
"Miscellaneous`SIUnits`"}, $Cool]]

Acceleration::usage = "Keyword"

CenterOfGravity::usage = "For the center of gravity, and related information, of a list of different co-ordinates and forces at those points.\nCenterOfGravity[Average, {c___List}] for the plain weighted average,\nCenterOfGravity[FindMinimum, {c___List}, options] for the true value, with options passed on to FindMinimum\nCenterOfGravity[p_List, {c___List}] with relevant scores for point p (having one dimension less than the ci)\nWith co-ordinates ci = {xi, yi, ..., lasti}, the last co-ordinate lasti is regarded as the force.\nThe output information also gives 'work' as the minimand"


Force::usage = "Keyword"
Frequency::usage = "Keyword = 1 / CycleTime"
CycleTime::usage = "Keyword = 1 / Frequency"


TorquePlot::usage = "TorquePlot[f, {dx, dy}, center_List:{0,0}, opts___Rule] gives a 2D display of the moment of a clockwise force at {dx, dy}+center, as seen from the given center and at a right angle with that center. See Results[TorquePlot]"

CounterTorquePlot::usage = "CounterTorquePlot[f, {dx, dy}, r, center_List:{0,0}, opts___Rule] displays the counterforce required at distance r from the center, for a force f at point {dx, dy}+center. See Results[CounterTorquePlot]"

Displacement::usage = "Displacement[t, a, v0:0] gives the displacement (in meters) for the time t in seconds (s), when v0 (m/s) is the start speed and a the constant acceleration (m/s^2)"

DisplacementTime::usage = "DisplacementTime[x, a, v0:0] gives the time (in seconds s) required to travel distance x (in meters), when v0 (m/s) is the start speed and a the constant acceleration (m/s^2)"


Elevator::usage = "Elevator[a, t1, t2, (b,) t] has acceleration a for 0 <= t <= t1, constant speed for t1 < t <= t2, and deceleration b (default -a) for t2 < t <= t3. Output is given as the triplet {acceleration, speed, location}. Default b = -a, and t3 = t2 + t1 (again). For an alternative value b (< 0), the t3 is computed, and given in Results[Elevator], in the quadruplets {a, v, s, t}. Also average speeds are given, in the phases and for the total"

Friction::usage = "Friction[v, fmax, fmin, a] gives the friction coefficient as a function of the speed v >= 0; fmax is the maximal friction at v = 0, fmin is the minimal friction at high speeds, and a (with a negative value) is the slope parameter.\nFor example Friction[v, .25, .20, -1]"

FrictionShow::usage = "FrictionShow[a, m:1, g:9.8, v0:0] gives a diagram of the forces involved with friction. Mass m (kg) is on a horizontal surface at point {0, 0} and gravitational constant is g (m/s^2). Mass m then is subjected to a horizontal acceleration a, but stays put because of frictional acceleration -a. The frictional constant is a/g or the tangens of the angle of the resultant force N + Fr with the normal N = - m g"

FromNewton::usage ="Gives the rule to translate Newton in kg m / s^2"

ToNewton::usage = "Gives the rule to translate kg into Newton s^2 / m"

Galilei::usage = "Galilei[x, y, m:1, g:9.8, v0:0] gives a diagram of a slope from {0, 0} to {x, y} and the forces involved for a mass m (kg), when the gravitational constant is g. The angle is alpha = ArcTan[y/x]. Without friction and initial speed v0, mass m moves from {x, y} to {0, 0}, with acceleration a = g Sin[alpha]. Alternatively, with friction and zero v0, the possible max friction parameter is Tan[alpha]. Results of the forces and the related points in the twodimensional space can be found in Results[Galilei].\nNote: Galilei used these ideas to show that gravity at sea level gives a constant acceleration."

Height::usage = "General keyword"
Area::usage = "General keyword"
Volume::usage = "General keyword"
Mass::usage = "General keyword"
VolumeFlow::usage = "General keyword for volume / time"
MassFlow::usage = "General keyword for mass / time"
Pressure::usage = "General keyword for force / area"
Density::usage = "General keyword for mass / volume"
Moment::usage = "General keyword for distance * force, eq. to Torque"
Torque::usage = "General keyword for distance * force, eq. to Moment"

Duration::usage = "Keyword to indicate duration"
TonneKilometer::usage = "Keyword to indicate distance * weight (similar to Work), not supported by Convert"
Kilometer::usage = "Keyword for Kilo Meter, not supported by Convert"
NWeight::usage = "Keyword to indicate weight (mass times gravitational force), expressed in Newtons"
Speed::usage = "Keyword to indicate speed = distance / time"
Work::usage = "Keyword to indicate distance * force, a form of energy"
Energy::usage = "Keyword to indicate energy, either work, potential or kinetic"
VolumeTon::usage = "Keyword to indicate 40 Feet^3"
CubicMeter::usage = "Keyword to indicate Meter^3"


GranularCone::usage = "GranularCone[{height, tangens, density, gravity:9.81}] gives the various aspects when a granular mass with given density is stored in a cone, with given height and tangens of the slope of that cone, where the tangens is the frictional coefficient as determined by gravity and granular specifics. Note: The output on pressure gives both the average over the whole area and the peak value in the center.\nGranularCone[x___Rule] is a SolveFrom application, using
\nNRadius == Height/ Slope,
\nArea == Pi * NRadius^2,
\nVolume == (Area  Height)/3, 
\nMass == (Area Height Density)/3, 
\nPressure[Center]== Gravity Height Density,
\nPressure[Mean] == 1/3 Pressure[Center]},
\n and default Gravity -> 9.81"



Hooke::usage = "Hooke[x___Rule] is an application of SolveFrom using the equations\n1) Elongation == Force / Area * Length / Elasticity,\n2) Stress == Force / Area,\n3) Strain == Elongation / Length"

Elongation::usage = "Keyword, used in Hooke[]"
Stress::usage = "Pulling force per area, used in Hooke[]"
Strain::usage = "Percentage elongation, used in Hooke[]"


PendulumGP::usage = "PendulumGP[h, x] gives a graphics primitive for a pendulum with height h and horizontal amplitude x.\nPendulumGP[h, x, G] gives the graphics primitive, while Results[PendulumGP] = {angle, height, {force along the angle, force to the center}} gives the result when the pendulum experiences a gravitational force G = m g"

PhPower::usage = "Keyword for physical power, to prevent confusion with Mathematica's Power"


PressureModel::usage = "PressureModel[{x__}, y___List, opts___Rule] is a 
SolveFrom application, using the model:
\n      Pressure == Height Density Gravity
\n      Volume == Height Area
\n      VolumeFlow == Volume / Duration
\n      Speed == Height / Duration,
\n      Mass == Volume Density
\n      MassFlow == Mass / Duration
\n      Force == Mass Gravity
\n      Work == Force Height
\n      PhPower == Work / Duration"


Resistance::usage = "Resistance[\"Air\", rho, A, c, v] gives the air resistance 1/2 rho A c v^2 for air density rho, coefficient c, frontal area A and speed v\nResistance[\"Roll\", f, m, g, alpha] gives the roll resistance f m g Cos[alpha] for friction coefficient f, mass m, gravitational constant g and angle alpha\nResistance[\"Slope\", m, g, alpha] gives the 'resistance' due to a slope m g Sin[alpha]\nResistance[\"Vehicle\", m, g, alpha, f, rho, A, c, v] adds air, roll and slope resistance"

Silo::usage = "Silo[x___Rule] is a SolveFrom application, with
\n	Area == Pi * NRadius^2,
\n 	Volume == Area  Height, 
\n 	Mass == Volume Density, 
\n	Pressure == Gravity Height Density
\n and default Gravity -> 9.81"

SplitRope::usage = "SplitRope[f, a, options] plots the forces involved when an object is lifted with force f and the split rope is fixed at angle a.\nLegend:\n   H1 and H2 are the points where the object hangs on the rope\n   Knot is the place where the split rope comes together, and where f is exerted\n   T1 and T2 are the forces along the split rope, as exerted by f\n   Conclusion: a small angle a causes huge forces T1 and T2";


TwoForces::usage = "TwoForces[F1, F2, options] plots forces F1 = {x1, y1} and F2 = {x2, y2}, and shows how the resultant is determined by adding the coordinates, as R = {x1+x2, y1+y2}\nNote: see ToPolar and FromPolar for a polar representation of forces"


Begin["`Private`"]
End[]
EndPackage[]
Print["This is a crippled package: it contains only the usage statements, no routines. Use of the proper software requires a user license.
See http://www.can.nl/~cool or write to Thomas Cool, Rotterdamsestraat 69, NL-2586 GH Scheveningen, Holland for ordering details"]
