(*********************************************************************

	Cool`Sampling`  package


 *********************************************************************)



(* :Author: Thomas Cool *)
(* :Copyright: Copyright 1995 Thomas Cool *)
(* :Package Version: 2.03 Thomas Cool, June 1998.*)
(* :Mathematica Version: 3.0 *)
(* :Keywords:    *)
(* :Limitation:  *)
(* :License: use of this software file requires a license usually available
      by payment of $10 to Swift account ING.B.NL.2A 3736767 to the name of 
      Thomas Cool, Rotterdamsestraat 69, 2586 GH Scheveningen, Holland.
      Please inquire about the cost of file packs.
      See the License[] function if Cool`Common` is present.  *)


Needs["Cool`Common`"]

BeginPackage["Cool`Sampling`",
Join[{"Cool`Statistics`Common`", 
"Statistics`ConfidenceIntervals`",
"Statistics`DiscreteDistributions`",
"Statistics`HypothesisTests`", "Statistics`DescriptiveStatistics`", "Statistics`DataManipulation`", "Statistics`NormalDistribution`", "Statistics`Common`DistributionsCommon`",
"Statistics`Common`PopulationsCommon`"}, $Cool]]

BinomialSample::usage = "BinomialSample[n, c, r:.2, opts] gives the sample results for a sample size of n and c successes. The 'Spread' gives the range of (1-r)c to (1+r)c, and the cumulative probabilities {from 0 till (1-r)c, between, from (1+r)c till n}. The StudentTCI gives the confidence interval for the mean, assuming the normal approximation; opts concerns the ConfidenceLevel for this"

BiNoPars::usage = "BiNoPars[p, n:1] gives the approximate parameters of a normal distribution {p, Sqrt[p (1 - p) / n]}, taken from a binomial distribution"

BiNoProxy::usage = "BiNoProxy[p, n] = NormalDistribution[p, Sqrt[p (1-p)/n]] gives the normal approximation to the binomial distribution (using the standard deviation for the mean). Use PDF and CDF on it"


Case::usage = "Case[i, ...] gives the sample size rule for case i. H0 and H1 are hypotheses, and alpha and beta the probabilities of error I and II. Generally, the input distributions concern the separate observations and the critical value is for the mean Sum[x[j]]/SampleSize, where the formulas take account of the fact that the variance of the mean depends upon the sample size
\n     n = sample size
\n     v = critical value
\n     for binomials: c = critical number = v n
\nCase[1, alpha, r, {mu, sigma}] for a normal distribution when, for relative accuracy r and symmetrically, Prob[mu (1-r) <= mean <= mu (1+r)] = alpha.
\nCase[\"1BiNoAbs\", alpha, abs, p] := Case[1, alpha, abs/p, BiNoPars[p]]
\nCase[2, alpha, beta, {mu0, sigma0}, {mu1_, sigma1_}] for two normal distributions.\nCase[3, alpha, beta, p0, p1] approximates binomials by using normal distributions with mu = pi and sigma = Sqrt[pi (1-pi)]. Note that OCCurve[v, {n,c}, NormalDistribution] = 50%.\n\nPlotting: Options are passed on to Plot. Results are in Results[Case].\n\nCase[Plot, 2, alpha, beta, {mu0, sigma0}, {mu1_, sigma1_}] for two normal distributions.\nCase[Plot, 3, alpha, beta, p0, p1, plotrange_List:{}, opts___Rule] provides a plot for case 3.\nSee SpecialCase"



CBiNoProxyInverseN::usage = "CBiNoProxyInverseN[level, {p0, p}] gives the sample size n to make the cumulative probability of BiNoProxy[p0, n] up to p equal to level"

CBiNoProxyInverseP::usage = "CBiNoProxyInverseP[level, {p0, n}] uses the sample size n to make the cumulative probability of BiNoProxy[p0, n] up to p equal to level, and gives p"



ControlChart::usage = "ControlChart[data_List, LCL, mean, UCL, opts] plots the control chart with lower control limit LCL and upper control limit UCL. The chart is centered at the mean value, and options are passed on to Show[]. The Results[ControlChart] contain RangeLists[data, {lcl, c, ucl}], of which the first are too low, the last are too high, and the others are below and above the mean. The process is in control when all data are between the LCL and the UCL."

CriticalValue::usage = "Option in output"


MDT::usage = "MDT[mu1_, var1_, n1_, mu2_, var2_, n2_, diff_,  opts___Rule] performs a mean difference test on two populations with mean mui, variance vari and number of observations ni. It is tested whether mu1 and mu2 differ by as much as diff. Note: the routine MeanDifferenceTest supplied with Mathematica has data lists as input, and MDT replaces this by the statistics mui, vari and ni. The options are the same as in MeanDifferenceTest"

Options[MDT] = Options[MeanDifferenceTest];


SampleSize::usage = "Option in output"

OCCurve::usage = "OCCurve[p, {n, c}] defines the Operating Characteristic Curve (probability of acceptance) in terms of parameter p (proportion of succes), for given n and c. This is: CDF[BinomialDistribution[p, n], c].\nOCCurve[p, {n, c}, PoissonDistribution] gives CDF[PoissonDistribution[p * n], c], which is a good Binomial approximation for n > 20 and p < .05, e.g. for continuous 3D plotting.\nOCCurve[p, {n, c}, NormalDistribution] gives the normal approximation CDF[NormalDistribution[p, Sqrt[p (1-p)/n], c/n]. Note: Use 
CDF[NormalDistribution[mu, sigma], fixed decisionvalue] as a function for mu for the OCCurve for continuous problems"

AverageOutgoingQuality::usage = "AverageOutgoingQuality[p, {n, c}, m] gives the average outgoing quality for lot size m, for the binomial distribution with parameter p, sample size n, critical number c (so that the probability of acceptance is OCCurve[p, {n, c}]. It is assumed that rejects in the sample are always replaced, while when the lot is rejected then all defects are replaced"

OCCurveInverse::usage = "OCCurveInverse[y_?NumberQ, {{n, c} (, ___)] gives the inverse, i.e. the probability x that makes the cumulative probability of acceptance equal to y"

OCContourPlot::usage = "Plots contours for (1) lists of n with c given, or (2) lists of c with n given. Note that ContourPlot does not work for integers. 
\nInput formats are:
\nOCContourPlot[ns_List, c_?NumberQ, range_List, d_:BinomialDistribution, opts___Rule]
\nOCContourPlot[n_?NumberQ, cs_List, range_List,	d_:BinomialDistribution, opts___Rule]
\n
\nYou can also get a graphics array with the alpha range on the left and the beta range on the right. Below a = {amin, amax} is the plot range in which alpha is located, and pa are the associated probabilities:
\n
\nOCContourPlot[GraphicsArray, n_?NumberQ, cs_List, {a_List, pa_List}, {b_List, pb_List},d_:BinomialDistribution, opts___Rule]
\nOCContourPlot[GraphicsArray, ns_List, c_?NumberQ, {a_List, pa_List}, {b_List, pb_List}, d_:BinomialDistribution, opts___Rule]
\nOCContourPlot[Map, ns_List, cs_List, {a_List, pa_List}, {b_List, pb_List}, d_:BinomialDistribution, opts___Rule] maps over cs
\nOCContourPlot[PlotLabel, ns_List, cs_List, {a_List, pa_List}, {b_List, pb_List}, d_:BinomialDistribution, opts___Rule] maps over cs but adds a label to the plot, of what is plotted
\n
\nNB. While OCCurve normally holds for values in the [0, 1] range, now the alpha and beta range apply to PERCENTAGES (i.e. horizontal only)
\nNB. Options are passed on to Show[]"

AlphaBetaGP::usage = "AlphaBetaGP[alpha, beta, {{n, c}, (__)}] makes a graphics primitive to use for plotting the coordinates of the 1-alpha and beta. It uses OCCurveInverse. If you have made a plot OCPlot of the operating curve, then Show[OCPlot, Graphics[AlphaBetaGP[...]]]"

AlphaBetaToLRRange::usage = "AlphaBetaToLRRange[alpha, beta] translates into the likelihood range, Mood & Graybill 1963:386"

SpecialCase::usage = "See Case for terms.\nSpecialCase[1, alpha, gamma, p0] adds the restriction, and computes, p1 = c/n = v = critical value. The critical value is no longer 'inbetween' but equals the value at the palpha point. Use the OCCurve to find implied beta's for other values of p. Gamma is the area to the left of p0 when assuming that v is the proper parameter. Note: since the area to the left of v is 50%, the area between p0 and v is 50% - gamma.\nSpecialCase[2, alpha, delta, p0] adds the restriction, and computes, p1 = c/n = v = critical value, as in case 2, but with delta probability. The pdelta point is found at the equality of both densities. To the left p0 is the likelier situation (when p0 applies). To the right p1 is the likelier situation (when p1 applies). The delta value is the probability up to pdelta when p1 is true. It gives the worst possible probability when p0 does not apply, that one would think that p0 still is likelier than the rejection of p0. Note that 50% - delta gives the probability, when p1 is true, that p1 is likelier than p0, while one still decides upon p0.\n\nPlotting:\nSpecialCase[Plot, 1, alpha, gamma, p0, plotrange_List:{}, opts___Rule] provides for special case 1.\nSpecialCase[Plot, 2, alpha, delta, p0] provides for special case 2"

Begin["`Private`"]
End[]
EndPackage[]
Print["This is a crippled package: it contains only the usage statements, no routines. Use of the proper software requires a user license.
See http://www.can.nl/~cool or write to Thomas Cool, Rotterdamsestraat 69, NL-2586 GH Scheveningen, Holland for ordering details"]
