(*********************************************************************

	Cool`Taxes`  package


 *********************************************************************)



(* :Author: Thomas Cool *)
(* :Copyright: Copyright 1996/97 Thomas Cool *)
(* :Package Version: 2.02,  August 1998*)
(* :Mathematica Version: 3.0 *)
(* :Keywords:    *)
(* :Limitation: *)
(* :License: use of this software file requires a license usually available
      by payment of $10 to Swift account ING.B.NL.2A 3736767 to the name of 
      Thomas Cool, Rotterdamsestraat 69, 2586 GH Scheveningen, Holland.
      Please inquire about the cost of packs. See the License[] function. *)

Needs["Cool`Common`"]

(*the FilledPlot package adjusts options of Graphics
in such a manner that CleanSlate` removes them again
in such a manner that Graphics no longer work.
The ResetAll function takes care of this*)



BeginPackage["Cool`Taxes`", Join[{"Graphics`FilledPlot`"}, $Cool]]



AddLinearRates::usage = "AddLinearRates[rates1_List, rates2_List, .....] where ratesi are the input format of PieceWiseLinear. Suppose that you have premiums for various funds, at ratesi, and that these premiums are additive, then this gives the cumulative rates structure that summarise the addition"

AdjustRates::usage = "AdjustRates[r_List, x] for r in TaxRates format,\nAdjustRates[r_List, x, y] for r in CurvedTaxRates format. It multiplies the tax brackets (and curvature parameter) with factor x (and y), without affecting the marginal rates. E.g. useful for adjustment to inflation"

AverageLevyRatio::usage = "AverageLevyRatio[w_, p_:Premium, t_:Tax] gives the average levy as a ratio to the gross wage: Levy[w, p, t] / w"

BenefitLine::usage = "BenefitLine[x_] := x - ReplacementRate Subsistence. Its intersection with the tax line gives minimum  income. Its intersection with the levy (taxes and premiums) line gives the minimum wage."

Bentham::usage ="Bentham[w_, r_:.5, x_:Exemption] = r (w - x) the basic tax system discussed by Bentham, here with a default marginal rate of 50%"

CurvedTax::usage = "CurvedTax[y_, x_:7.102, r_:.6, c_:31] gives a nonlinear curved tax relation for income y, exemption x, limit value r of the marginal rate, and curve parameter c.\nThe relation is r (y - x)  y / (y + c). The Bentham tax is r (y - x), and y / (y + c) adds curvature. A positive c gives a convex function, a negative a concave function. Maximum conditions are used to guarantee useful output."

CurvedTaxRates::usage = "An example input for PieceWiseCurved"

DynamicMarginal::usage = "DynamicMarginal[w, wi, pri:1, ti:Automatic] gives the d.m.r. (newlevy - Levy[w]) / (newwage - w), when wages are indexed with wi, premium with pri, and tax with ti. The indexed levy is computed using Indexed[...]. Automatically ti is taken equal to pri.\nDynamicMarginal[All, w, wi, pri, ti:Automatic] gives more information on the specific point"

Exemption::usage = "The theoretical exemption, equal to the net minimum wage, equal to the current value of Subsistence * ReplacementRate"

FindMinimumWage::usage = "FindMinimumWage[p_:Premium, t_:Tax] computes MinimumWage and MinimumIncome, assuming values for Subsistence and ReplacementRate. See NetIncome."

GrossToNetRatio::usage = "GrossToNetRatio[w_, p_:Premium, t_:Tax] gives the rato of the gross to the net wage: w / NetIncome[w, p, t]"

Indexed::usage = "Indexed[Tax][y, ti] and \nIndexed[Premium][w, pri]\n   give the Tax and Premium when the rates are adjusted by ti and pri. E.g. by default taxes are indexed as PieceWiseLinear[y, AdjustRates[TaxRates, ti]]"

Levy::usage = "Levy[w_, p_:Premium, t_:Tax] gives the total burden of tax and premium combined."

LevyPlot::usage = "LevyPlot[b_:0, e_:130, p_:Premium, t_:Tax, opts___Rule] plots for the range of b to e:\n1) the levy line,\n2) the 45-degrees line (so that the difference between levy and the 45-degree line gives net income),\n3) the benefit line (i.e. that part of net income that is required for subsistence and the replacement rate),\n4) the minimum wage given by the intersection of levy and benefit line. See Results[LevyPlot]\nPlot options apply mainly to (1).\nNote that setting Premium to zero gives the tax line and minimum income. Beware, though, that the x-axis then gives income and not wages.\nNote that there is a levy void below the minimum wage, since people may not be allowed to work below it, thus don't earn anything that can be taxed. This point is clarified by the option Filled -> True"


MinimumIncome::usage = "A reserved name"

MarginalRate::usage = "MarginalRate[f_, y_(, y0_)] gives the marginal rate for a function f, either as a function of y or at a point y0. Input formats are: \n   MarginalRate[t[y], y (, y0)], or \n   MarginalRate[t, y (,y0)] or even \n   MarginalRate[t, y0].\nThe rate is computed as (t[y + .001] - t[y]) / .001, since, when the tax function has Max and/or Min statements, the derivative gives problems"

MinimumWage::usage = "A reserved name, giving the minimum wage found by FindMinimumWage[] or SolveMinimumWage[]"

NetIncome::usage = "NetIncome[w_, p_:Premium, t_:Tax] where p[w] and t[y] must be premium and tax functions with one variable only. \nIncome y and wages w are considered gross values, and measured in thousands DFL 1997, where $1 =  1.7 DFL. Net values are termed NetIncome and/or NetWage.\nBy definition: Income = Wage - Premium[Wage], so that taxable income remains after deduction of premiums. Then NetIncome = Income - Tax[Income].\nSince 'income' is a proper term for the wage after deductions of premiums, the term 'NetWage' applies to the net value after deduction of both taxes and premiums. Note that NetIncome = NetWage for those who don't have other sources of income."

NetIncomePlot::usage = "LevyPlot[b_:0, e_:130, p_:Premium, t_:Tax, opts___Rule] plots for the range of b to e:\nPlots the same result as LevyPlot, but then translated into net income. Thus:\n1) the net income line,\n2) the 45-degrees line (so that the difference between net income and the 45-degree line gives the levy),\n3) the benefit line, now horizontal (i.e. that part of net income that is required for subsistence and the replacement rate),\n4) the minimum wage given by the intersection of net income and benefit line. See Results[NetIncomePlot]\nPlot options apply mainly to (1).\nNote that setting Premium to zero gives the tax line and minimum income. Beware, though, that the x-axis then gives income and not wages.\nNote that there is a levy void below the minimum wage, since people may not be allowed to work below it, thus don't earn anything that can be taxed. This point is clarified by the option Filled -> True"

PieceWiseLinear::usage = "PieceWiseLinear[y, rates_List] constructs a piecewise linear function. The rates are given as pairs, {{x1, r1}, {x2, r2}, ...} where xi is the point where the slope (marginal rate) ri starts to be effective. It is assumed that x1 is proper exemption, so that the slope from 0 till x1 is zero. The variable y is the variable used in the function.\nDefining Tax[y_] = PieceWiseLinear[y, rates] gives you the tax function to work with. It is optional to Simplify it. The function uses If-statements so that it can be differentiated. "

PieceWiseCurved::usage = "PieceWiseCurved[y_, rates_List] constructs a piecewise curved function. The rates are given as triplets, {{x1, r1, c1}, {x2, r2, c2}, ...} where xi is the point where the limit slope (marginal rate) ri and curvature ci start to be effective. It is assumed that x1 is proper exemption, so that the slope and curvature from 0 till x1 are zero. An example is CurvedTaxRates. The variable y is the variable used in the function.\nDefining Tax[y_] = PieceWiseCurved[y, rates] gives you the tax function to work with. It is optional to Simplify it. The function uses If-statements so that it can be differentiated."

PiecewiseWhich::usage = "PiecewiseWhich[x_Symbol, rates_List] is essentially the same as PieceWiseLinear, but, as an application of ToPiecewiseLinear, it creates a Which object"

Premium::usage = "Premium[w] gives the social security premium, by default referred to by other routines like NetIncome. When reading in the package it is defined as PieceWiseLinear[w, PremiumRates]. You can of course define your own Premium[w_] function."

ReplacementRate::usage = "A reserved name, with default value 1.10. See BenefitLine"

SetTaxAndPremium::usage = "SetTaxAndPremium[p, t] clears the Tax and Premium functions, and defines them as piecewise linear functions, while setting TaxRates = t and PremiumRates = p. SetTaxAndPremium[] resets to the defaults. Defaults approximate the situation in Holland 1997 for a single person"  

SolveMinimumWage::usage = "SolveMinimumWage[p_:Premium, t_:Tax] tries for an algebraic solution of the MinimumWage and MinimumIncome, assuming values for Subsistence and ReplacementRate. It only works when p and t are proper algebraic relations (e.g. no If statements). See NetIncome and FindMinimumWage."

Subsistence::usage = "A reserved name, with default value 19. See BenefitLine"

Tax::usage = "Tax[y] gives the tax, by default referred to by other routines like NetIncome. When reading in the package it is defined as PieceWiseLinear[y, TaxRates]. You can of course define your own Tax[y_] function."

TaxCredit::usage = "Only a keyword. If you want to assign a Tax function with a tax credit, you might Clear[Tax] and define:\nTax[y_]=Max[0,PieceWiseLinear[y,TaxRates]-TaxCredit]"

TaxDeduction::usage = "Reserved keyword, not implemented. It is optional for you to take account of tax deductions, e.g. by the following definitions:\n   TaxDeduction[y_]  = 1.1 y\n   ProperTax[y_] = PieceWiseLinear[y, TaxRates]\n   Clear[Tax]\n   Tax[y_] := ProperTax[y - TaxDeduction[y]]"

TaxRates::usage = "A reserved name. See PieceWiseLinear. See its default value. Note that you have to Clear[Tax[ and redefine Tax[x_] = ... to make another TaxRates effective"

PremiumRates::usage = "A reserved name. See PieceWiseLinear. See its default value. Note that you have to Clear[Premium[ and redefine Premium[x_] = ... to make another PremiumRates effective"

TaxOnWage::usage = "TaxOnWage[w_, p_:Premium, t_:Tax] gives the tax on the wage w base instead of the income y base"

Total::usage = "Total[f_:Identity, b_:0, e_:Infinity] gives the integral of f[x] weighted with the WageDensity at x, for the interval of b till e. By default f = Identity, and the wage sum is computed. Special forms are:\nTotal[Number, b_:0, e_:Infinity] gives the integral of the wage density, i.e. the total number of labour years. This could also be got by setting f[x_] = 1.\nTotal[\"Wage\", b_:0, e_:Infinity] also computes the wage sum, but it is thought that \"Wage\" reads better than Identity.\nUse SetOptions[NIntegrate, ...] if you want to adjust the computational parameters."

ToPensParade::usage = "ToPensParade[density_, n_Symbol] translates an income density (with integral value of 1) into the 'Parade' originated by professor Jan Pen. Use this function for example as (with values for m and s):\n    PP[n] = ToPensParade[WageDensity[#, m, s, 1]&, n]\n    Plot[PP[n], {n, 0, 1}]\nPen's Parade is the inverse of the integral of the density. Variable n is a proportion of the population, and PP[n] is the income level associated with it.\nThink of the population passing by in a parade of one hour, all ordered by the height of their incomes. For a common distribution you have to wait 40 minutes before you encouter people of medium income."

WageDensity::usage = "WageDensity[x_, m_:3.85, s_:.5, n_:8] gives n times the lognormal density at x, for lognormal parameters m and s. Thus n equals NIntegrate[ WageDensity[x], {x, 0, Infinity}] and gives the total number of labour years involved (measured in millions)"

Begin["`Private`"]
End[]
EndPackage[]
Print["This is a crippled package: it contains only the usage statements, no routines. Use of the proper software requires a user license.
See http://www.can.nl/~cool or write to Thomas Cool, Rotterdamsestraat 69, NL-2586 GH Scheveningen, Holland for ordering details"]
