(*********************************************************************

	Cool`Tool`  package


 *********************************************************************)



(* :Author: Thomas Cool *)
(* :Copyright: Copyright 1993/97 Thomas Cool *)
(* :Package Version: 2.13 Thomas Cool, August 1998.*)
(* :Mathematica Version: 3.0.0  *)
(* :Keywords: Miscellaneous, Variations on Themes *)
(* :Limitation: *)
(* :License: use of this software file requires a license usually available
      by payment of $10 to Swift account ING.B.NL.2A 3736767 to the name of 
      Thomas Cool, Rotterdamsestraat 69, 2586 GH Scheveningen, Holland.
      Please inquire about the cost of packs. See the License[] function. *)

Needs["Cool`Common`"]

BeginPackage["Cool`Tool`", {"Cool`Common`", "Cool`Context`", "Cool`List`",
	"Cool`Manager`"}]

Bank::usage = "A simple data bank routine. Your Bank[Data] is a multidimensial data array. You simply display with TableForm. But the TableHeadings can be used to select an element. We can extend this search to finding a value that must be within a range of subsequent TableHeadings values.
\n
\nExample 1:
\nBank[Data] = Array[entry, {2, 3, 4}] ; (*three dimensions*)
\nBank[TableHeadings] = {{u, v}, {AA, BB, CC}, {120, 110, 100, 70}};
\nBank[Range] = {}  (*no search in ranges, for no dimension*)
\nBank[Show]
\nBank[Take, u, BB, 70]
\n
\nExample 2:
\nBank[Data] = Array[entry, {2, 3}] ; (*two dimensions*)
\nBank[TableHeadings] = {{{0, 10}, {10, 20}}, {AA, BB, CC}};
\nBank[Range] = {True, False} (*search in range for first dimension*)
\nBank[Show]
\nBank[Take, 5, BB] (*will find the value 5 in the range {0, 10}*)"

Between::usage = "Between[x_?NumberQ, y_List] finds the pairs of subsequent values in y - thus {y[[i]], y[[i+1]} - for which x is between these. If y is sorted - or give Between[x, Sort[y]] - then this gives the maximal ymin and the minimal ymax elements in y such that ymin < x < ymax"

BowElasticity::usage = "BowElasticity[f_, p_, q_] gives the bow elasticity when a point {p, f[p]} moves to {q, f[q]} for a function f[];\nBowElasticity[{p_, y1_}, {q_, y2_}] when only data are given; the bow elasticity B and coefficient c solve y1 == c p^B and y2 == c q^B";

ClearFunctionByString::usage = "ClearFunctionByString[c_String][x_String] where Clear[] does not work"

CombineRules::usage = "CombineRules[{r__Rule}] gives combinations of rules including {}"

DeleteRule::usage = "DeleteRule[x_, h__] deletes rules in x with Heads h"

DQ::usage = "DQ[f, x] tests whether f is a function of x. If False, then the message is printed that taking the (partial) derivative f'[x] could be irrelevant."

Elasticity::usage = "Elasticity[f_, x_] = x / f[x] * D[f[x], x] or \nElasticity[f_, g_, t_] = dLog[f] / dLog[g] with common variable t\nFor multivariates: either use direct functions, e.g. f[x1, x2, #, x4]& or like Elasticity[f[t, w], g[s, t, w], t]"

GrowthRate::usage = "GrowthRate[f, x] = D[Log[f[x]], x] = D[f[x], x] / f[x] or\nGrowthRate[f_[y___], x_] or\nGrowthRate[f, g, x] if f[x] and g[x] are given but the growth of f with respect to g is required"


GeneralizedStringTake::usage = "GeneralizedStringTake[x_,k_Integer, rigorous_Symbol:All] \n takes the first k positions, even in lists. If All, then expressions are transformed into strings."

InRange::usage = "InRange[x_?NumberQ, pairs_List] finds the list of pairs in the list of pairs that makes InRangeQ[x, pair] True"

InRangeQ::usage = "InRangeQ[x, {lt, ge}] tests (lt < x <= ge)"

IntegerSCM::usage = "IntegerSCM[s_List] finds the smallest common integer multiplier k such that k s are all integer. Works for rational numbers in s only"

LinExp::usage = "LinExp[p, {A, a, pstar, h}] translates the exponential function A p^a (i.e. with elasticity a) with a linear additive constant c = - h A pstar^a, in such manner that the functional value and elasticity at point pstar remain the same. \nq[p] = LinExp[p, {pstar, h}, qstar] gives the LinExp function such that if the function is a demand function, then maximisation of revenue p q[p] is at p = pstar, with demand qstar = q[pstar]"

LogRule::usage = "A list of rules to expand logarithms"

NestHead::usage = "NestHead[f_, x_] maps Head f over x and the generated (sub-) result, until the (sub-) result of any level no longer is a List. Apply for example on f[x] = {x1, x2} and f[x2] = {y1, y2, y3}."

NIntegrateToFirstZero::usage = "NIntegrateToFirstZero[f, p_?NumberQ, 
opts___Rule] finds the intersection with the horizontal axis closest to p, and integrates from p to this point. Subresults are in Results[
NIntegrateToFirstZero], namely all intersections with the horizontal axis, the selected one, and the direction of the operation (i.e. to the left or to the right). Also provided is the startpoint Point -> {p, f[p]}. Options are passed on to NIntegrate"

NSolveLinearDynamics::usage = "NSolveLinearDynamics[M_List, x0_List,  T_Integer] computes the linear dynamic system x[t] = M^t x0 for t = 0, ..., T\nNSolveLinearDynamics[M_List, x0_List, e_List] computes x[t] = M^t x0 + e[[t]]"


OnOffFlow::usage = "OnOffFlow[x, {t1, t2, ..., tn}][t] gives value x if t is in the interval [ti, ti+1) for uneven i, and 0 otherwise. Value x may be a function of t.\nNote: use for example as\n   f = OnOffFlow[10, {0, 1, 2, 3}];\n   Plot[f[t], {t, 0, 4}]";

PaddedString::usage = "PaddedString[x_String, p_Integer, d_Integer] adds blanks around a string: d to the right and possibly some to the left - up to a total of p places alltogether"

PointOfIntersection::usage = "PointOfIntersection[f_, g_, k_:1] for Real valued functions f and g \n finds the k-th solution x = a for f[x] = g[x] and renders {a, f[a]}"

Options[PrintPrepare] = Join[Options[PaddedForm], {Places -> 10, Decimals -> 2}]

PrintPrepare::usage = "PrintPrepare[x_, r___Rule] padds strings, integers and reals with blanks for printing in columns (PaddedForm seems unreliable)"

RealRootQ::usage = "RealRootQ[f_, x_] tests whether x is a real root"

RealRoots::usage = "RealRoots[sols] selects the real roots (sols provided by Solve)" 

ReplaceByHeadCount::usage = "ReplaceByHeadCount[expr_, x_, head_] replaces item x in expr by head[x, int] where int is the count of occurrences within expr. If x is a list, then replacement is folded over x."


Options$Logistic =  {Right -> 0, Center -> 0, Range -> 1, Slope -> 1};

Options[Logistic] = Options$Logistic

Logistic::usage = "Logistic gives the Logistic function a.k.a. Sigmoid.\n1) Logistic[x] uses the parameter values given by Options[Logistic].\n2) Logistic[x, {right, center, range, slope}] uses the mentioned parameter values.\nBoth: Note that 1 parameter is redundant"

Right::usage = Key[AddedUsage, Right, "Option of Logistic, for the rightward shift of the Logistic. Default is 0."];
Center::usage = Key[AddedUsage, Center, "Option of Logistic, for the upward shift of the Logistic. Default is 0."];
Range::usage = Key[AddedUsage, Range, "Option of Logistic, for the range of the Logistic. Default is 1."];
Slope::usage = "Option of Logistic, for the slope of the Logistic. Default is 1.";

SawTooth::usage = "SawTooth[t, a, b, c:0] gives the saw-tooth function common for inventories, y = a - b x with x = Mod[t, a / b]. Here a is the order quantity and b is the demand rate, so that a / b is the period of supply. Maximum storage can be set to a - b c for some period c, but the presumption then is that demand is serviced from another storage location"

SimplifyBy::usage = "SimplifyBy[expr, {rules___Rule}, opts___] applies rules repeatedly and Simplify's using opts."

SimplifyBySolve::usage = "SimplifyBySolve[expr_, By_:Automatic, expandq_:True, printq_:True, opts___Rule] tries to simplify an expression by first solving for By and then back-solving for the expression again. This works at least in some cases where powers are involved. If expandq, first Simplify[PowerExpand[expr]]. If By === Automatic, then presently Return. If printq, print intermediate results. The options are for Solve."
SolveGeneral::usage = "SolveGeneral[x, {t___}] means If[x, (*true*){{t -> All}}, (*false*) {{t->Null}}, Solve[x, {t}]] ; x can be single or a List"

Solve2List::usage = "Solve2List[x_List, {t___}] :=  SolveGeneral[Simplify[Apply[Equal, x]], {t}], sets the two elements of x to an equation and solves for t"

SolveLHS::usage = "SolveLHS[x__] solves equations x for the left hand variables"

SolveFrom::usage = "SolveFrom[eqs_list, {x___Rule}, (elims___List,) opts___Rule] defines the equations to solve as neweqs = eqs /. {x}, finds the unassigned variables in these neweqs, and solves for these. The elims list have two functions: elims1 is passed on as the elims of Solve, elims2 are only eliminated from the unassigned variables that the routine has noted. (For example, if variables have dimensions such as Meter or Second, then you would not want to solve for these.) Output consists of neweqs and the solution\nNote: One often has a constant set of equations but different selections of unknowns. Define model[{x___Rule}] := SolveFrom[modelequations, {x}, opts] and then investigate different model[...] solutions. See Cool`Model` for the use of lags.\n\nUse SolveShow[Last[result]] to present the solution. The input parameters are not shown\nSolveFrom[TableForm, results___List] takes the outputs from various calls of SolveFrom and gives a TableForm presentation of these, now including the different input parameters {x}.\n\nNote: SolveFrom uses Variables[] to find the variables to solve. Variables however is only defined for polynomials. To enable the routine to find other variables, problematic expressions should be replaced by e.g. List. Use the option Rule for this. E.g. Rule -> {Log -> List} will SolveFrom allow to find A in Log[A]"

SolveFormally::usage = "SolveFormally[eqns, vars (, elims), options], same format as Solve. This replaces numbers by dummy variables, applies Solve with options, and substitutes the numbers back. This can generate quicker results since Solve sometimes appears stronger when no numbers are present."

SolveShow::usage = "SolveShow[r_List, opts___Rule] presents the results r of Solve in TableForm, sorted. Missing values in certain solutions are represented by \".\". Options are passed on to TableForm"

SortSameQ::usage = "SortSameQ[x_, y_, test_] := test[x,y] && test[y,x], where the test can also be used in Sort"

StringListQ::usage = "StringListQ[a_List] tests whether the a[[i]] are Strings"

StringListPralse::usage = "StringListPralse[x_List] pralses when the elements of x are not Strings"

StringToList::usage = "StringToList[x_String] turns a sentence into a list of words, while blanks are regarded as separators"


ToPattern::usage = "ToPattern[x_List, head_:Blank] creates a rule for the variables in x, that can be used to change an expression into a pattern; = Map[ Rule[#, Pattern[#, head[]]]&, x]"

ToPiecewise::usage = "ToPiecewise[x_Symbol, {limit1, value1, limit2, value2, ...}, opts___Rule] creates a Which object. The latter object normally is created as easy by simply typing it, but, one can imagine instances in which a routine like this may be useful. Use as:\nf[x_] = ToPiecewise[x, {0, 0,  1, x^2,   2, x}, Append -> {True, x^2}]. The default function option setting is Function -> Less"

ToPiecewiseLinear::usage = "ToPiecewiseLinear[x_Symbol, {limit0, r0, c}, {
limit1, r1, limit2, r2, ...}, opts___Rule] creates a Which object for a 
piecewise linear function in terms of variable x. To the utmost left, the 
function starts as r0 x + c, for x < limit0. Then in steps to the right, the slope or marginal rate ri is valid for limit(i-1) till limit(i). \nDefine e.g. f[x_] = ToPiecewiseLinear[x, {a, b, c}, rates] gives you the proper function to work with. The options are as in ToPiecewise[]"


UnPattern::usage = "UnPattern[y_] := y /. Pattern -> Composition[First, List]"

XXPlusSpace::usage = "XXPlusSpace[x_List, tr_:True] projects x in the {x[[i]], x[[i+1]]} space.\nIf True, output =  {{x[[1]], x[[2]]},  {x[[2]], x[[3]]}, ... } (sequential).\nIf False, output =  {{x[[1]], x[[2]]}, {x[[2]], x[[2]]}, {x[[2]], x[[3]]}, ... } (block seq.)\nMake a PlotLine of the two versions to see the difference. See PhaseDiagram.\nNote: results are stored in Results[XXPlusSpace, tr]."


Begin["`Private`"]

ClearFunctionByString[f_String][x_String] := 

	               ToExpression[ f <> "[\"" <> x <> "\"] =. "]

CombineRules[y_List] := 

		Module[{f, len, propid, $property, $identity, k, x}, 
		len = Length[y]; 
		propid = Array[{$identity, $property[#]}&, len];
		k = Outer[f, Apply[Sequence, propid]];
		Evaluate[Array[$property, {len}]] = Map[List, y];
		k /. {$identity -> {}, f -> Join}
		] (* end module*)



DeleteRule[][y_] := ((y -> x_) :> ToSequence[])

DeleteRule[z_, y__] := z /. (DeleteRule[] /@ Flatten[{y}])

DeleteRule[x_] := x

D::used ="D[`1`, `2`] may be irrelevant since `1` is not an explicit function of `2`";

DQ[f_, x_] := If[Position[f, x] === {}, Message[D::used, f, x];False, True]

Bank[Show, opts___Rule] := 
	TableForm[Bank[Data], opts,
	TableHeadings -> Bank[TableHeadings]]

Bank[Range] = {}

Bank::len = "There must be `1` query keys";
Bank::mis = "Unknown query keys or wrong order: `1`";
Bank::ran = "Bank[Range] =!= {}, but of deficient length `1`";

Bank[Take, k__] := 	
		Module[{a, n, m, pos, lis = {k}},
		n = Length[lis]; 
		m = Length[Bank[TableHeadings]];
		If[n =!= m, Message[Bank::len, m]; Return[]];
		If[Bank[Range] =!= {}, 
		If[Length[Bank[Range]] =!= n, Message[Bank::ran, n]; Return[]];
		    m = Transpose[{Bank[Range], lis, Range[n]}];
		    lis = If[First[#] =!= True,#[[2]], 
		    First[InRange[#[[2]], 
				Part[Bank[TableHeadings], #[[3]]]]]]& /@ m];
		a = Thread[a[Bank[TableHeadings], lis]] /. a -> Position;
		If[MemberQ[a, {}], 
			pos = Position[a, {}];
			pos = TakeElements[lis, pos];
			Message[Bank::mis, pos]; Return[]];
		Part[Bank[Data], Sequence @@ Flatten[a]]] 

InRangeQ[x_, {lt_, ge_}] := (lt < x <= ge)

InRange[x_?NumberQ, ran_List] :=
	Module[{pos},
	pos = Position[InRangeQ[x, #]& /@ ran, True];
	TakeElements[ran, pos]]
	
Between[x_?NumberQ, y_List] := InRange[x, XXPlusSpace[y]]
 
BowElasticity[{p_, x_}, {q_, y_}] := Log[y/x] / Log[q/p]

BowElasticity[x_, p_, q_] := Log[x[q] / x[p]] / Log[q/p]



Elasticity[f_Symbol, x_?(!NumberQ[#]&)] := x D[f[x],x] / f[x]
Elasticity[f_Function, x_?(!NumberQ[#]&)] := x D[f[x],x] / f[x]

Elasticity[f_[y___], x_?(!NumberQ[#]&)] := x D[f[y],x] / f[y]

Elasticity[f_, g_, t_?(!NumberQ[#]&)] := Module[{ft, gt}, 
		(*to allow mixed input formats*)
		ft = If[MemberQ[{Symbol, Function}, Head[f]], f[t], f];
		gt = If[MemberQ[{Symbol, Function}, Head[g]], g[t], g];
		D[Log[ft], t] / D[Log[gt], t]]

GrowthRate[f_Symbol, x_?(!NumberQ[#]&)] := D[f[x],x] / f[x]
GrowthRate[f_Function, x_?(!NumberQ[#]&)] :=  D[f[x],x] / f[x]

GrowthRate[f_[y___], x_?(!NumberQ[#]&)] := D[f[y],x] / f[y]

GrowthRate[f_, g_, t_?(!NumberQ[#]&)] := Module[{ft, gt}, 
		(*to allow mixed input formats*)
		ft = If[MemberQ[{Symbol, Function}, Head[f]], f[t], f];
		gt = If[MemberQ[{Symbol, Function}, Head[g]], g[t], g];
		D[ft, t] / D[gt, t] / ft]


GeneralizedStringTake[x_,k_Integer, rigorous_Symbol:All] := 

	Module[{tem},
	Switch[Head[x],
		List, Map[GeneralizedStringTake[#,k,rigorous]&, x],
		String, StringTake[x, Min[StringLength[x], k]],
		_, If[rigorous === All, tem = ToString[x]; 
			StringTake[tem, Min[StringLength[tem], k]],x]]
	] (*end module*)

IntegerSCM[s_List] :=
	Module[{k, sel, take, f, d},
	k = Union[Denominator /@ s];
	sel = {}; take = k;
	Do[f = First[take]; take = Rest[take];
		d = (Divisors /@ take) // Flatten // Union;
		If[MemberQ[d, f],  AppendTo[sel, i]],
        {i, Length[k]}];
	k = If[sel =!= {}, Delete[k, List /@ sel], k];
	Times @@ k]


LinExp[x_, {A_, a_, p_, h_}] := (1+h) A (p^h x)^(a/(1+h)) - h A p^a

LinExp[x_, {p_, h_}, q_] :=	LinExp[x, {p  q, -1, p, h}]

LogRule = {Log[x_/y_] -> (Log[x] - Log[y]),
		Log[Times[x__, y_]] -> (Log[Times[x]] + Log[Times[y]]),
		Log[Power[x_, y_]] -> y Log[x]}

NestHead[f_, x_] := Module[{a = f[x]},
	If[ListQ[x], NestHead[f, #]& /@ x, If[ListQ[a], NestHead[f, a], x]]]

NIntegrateToFirstZero[f_, p_?NumberQ, opts___Rule] :=
	Module[{x, pos, pm, psel, res},
	pos = x /. NSolve[f[x] == 0, x];
	pm = pos - p;
	psel = TakeElements[pos, Position[pm, Max[pm]]][[1]];
	res = NIntegrate @@ {f[x], {x, p, psel}, opts};
	Results[NIntegrateToFirstZero] = {
	Point -> {p, f[p]}, 
	"Solve[f[x] == 0]" -> pos,
	Select -> psel, 
	Direction -> If[psel >= p, Right, Left, Indeterminate],
	NIntegrate -> res};
	res]

NSolveLinearDynamics[Mat_List, x_List] := Mat . x

NSolveLinearDynamics[Mat_List, x_List,  n_Integer] := 
		NestList[NSolveLinearDynamics[Mat, #]&, x, n]

NSolveLinearDynamics[M_List, x0_List, e_List] := 
		Module[{x, t, n}, n = Length[e]; 
		x[0] = x0; x[t_] := M . x[t-1] + e[[t]]; Array[x, n] ]

OnOffFlow[x_, ts_List][t_] :=
	Module[{a, b, c, d, e},
	a = XXPlusSpace[Append[ts, Infinity]];
	b = (First[#] <= t < Last[#])& /@ a;
	d = Position[b, True];
	c = If[d === {}, True, e = d[[1, 1]]; EvenQ[e]];
	If[c, 0, x]
	](*end module*)

PrintPrepare[x_, r___Rule] := 

	Module[{p,d},
	p = Places /. {r} /. Options[PrintPrepare];
	d = Decimals /. {r} /. Options[PrintPrepare];
	Switch[Head[x],String, PaddedString[x,p,d+1],
	List, Map[PrintPrepare[#,r]&,x],
	Integer, PaddedString[ToString[x], p,d+1],
	Real, PaddedString[ToString[PaddedForm[x, {p-d-1,d}, 
		OptionsFilter[PaddedForm, r]]],p,0]]
	]


PaddedString[x_String, p_Integer, d_Integer] :=

	Module[{n,lef,rig,leftString,rightString},

	n = StringLength[x];
	rig = Max[0, Min[n + d, p] - n];
	lef = Max[0, p - n - rig];
	rightString = StringTake["                          ",rig];
	leftString = StringTake["                           ",lef];
	leftString <> x <> rightString]


PointOfIntersection[f_, g_, k_:1] := 

	Module[ {a, c, x }, c = Solve[ f[x] == g[x], {x}]; a = x /. c[[k]]; {a, f[a]}]

RealRootQ[f_, l_] :=  Module[{a, b},
	If[Position[ l /.  Complex[a_, b_] -> False , False] =!= {}, False, f -> l]]

RealRoots::act = "Real roots taken only. Enter Dump[RealRoots] to see all."

RealRoots[sols_] := Module[{len = Length[sols], s},
	s = Select[sols /. Rule -> RealRootQ, AllQ[#,  (!SameQ[#, False])&]&];
	If[len =!= Length[s], Dump[RealRoots] = sols; Message[RealRoots::act]]; s]

ReplaceByHeadCount[expr_, x_List, head_] := 
		Fold[ReplaceByHeadCount[#1, #2, head]&, expr, x]

ReplaceByHeadCount[expr_, x_, head_] :=

	Module[{pos}, 
	pos = Position[expr, x];
	Fold[ReplacePart[#1, head[x, Position[pos, #2][[1,1]]], #2]&, expr, pos]]

Logistic[x_] := Logistic[x, {Right, Center, Range, Slope} /. Options[Logistic]]

Logistic[x_, {xshift_, yshift_, r_, s_}] :=  r / (1 + E^(-s (x - xshift))) + yshift

SawTooth[t_, a_, b_, c_:0] := Min[ a - b c, a - b Mod[t, a / b]]

SimplifyBy[expr_, {rules___Rule}, opts___] := 
		FixedPoint[Simplify[# /. {rules}, opts]&, expr]

SimplifyBySolve[expr_, by_:Automatic, expandq_:True, printq_:True, opts___Rule] := 
	Module[{x, eq, y, sol}, 
	x = If[expandq, Simplify[PowerExpand[expr]], expr];
	If[by === Automatic, Return[x]];
	eq = (x == y); sol = Solve[eq, by, opts]; 
	If[printq, Print[sol]];
	sol = sol[[1,1]];
	sol = First[sol] -> Simplify[PowerExpand[Simplify[Last[sol]]]]; 
	If[printq, Print[sol]];
	eq = Equal @@ sol; sol = Solve[eq, y, opts];
	Simplify[PowerExpand[Simplify[ y /. sol[[1]] ]]]
	] (*end module *)

SolveFormally[eqns_, vars_, elims___, opts___Rule] := 
	Module[{d, pos, x, k, r, s, v, e, rulev, rulee}, 
	rulev = SymbolArrayRule[Flatten[{vars}], v];
	rulee = SymbolArrayRule[Flatten[{elims}], e];
	d = eqns /. rulev /. rulee;
	pos = Position[d,  x_?NumberQ];
	r = SymbolArrayRule[TakeElements[d, pos], k];
	d = d /. r;
	s = Solve @@ {d, Last /@ rulev, Last /@ rulee, opts };
	s /. eluR[r] /. eluR[rulev] /. eluR[rulee]] (*end Module*)

Options[SolveFrom] = {Rule -> {}}

SolveFrom::fal = "With this assignment, equation(s) `1` is (are) inconsistent"

SolveFrom::nos = "With this assignment, there is no solution (model inconsistency)"

SolveFrom::len = "It may be a tip to make the number of equations (now `1`) equal to the number of variables (now `2`), e.g. by using elimination"

SolveFrom[lis_List, {x___Rule}, elims___List, opts___Rule] := 
		Module[{n, var, y, pos, k}, 
		y = lis /. {x};
		pos = Position[y, False];
		If[pos =!= {}, Message[SolveFrom::fal, pos];Return[]];
		y = y /. True :> ToSequence[];
		n = y /. {Equal -> List} /. {opts} /. 
						(Rule /. Options[SolveFrom]);
		var = Variables[n];
		Results[SolveFrom] = {n, var};
		If[Length[{elims}] =!= 0, 
			var = Complement[var, Flatten[{elims}]];
			Results[SolveFrom] = Append[Results[SolveFrom], var]];
		k = Solve[y, var, 
				If[{elims} === {}, ToSequence[], First[{elims}]], 
				OptionsFilter[Solve, opts]];
		If[k === {}, Message[SolveFrom::nos];
			If[Length[var] =!= Length[y],
			Message[SolveFrom::len, Length[y], Length[var]]]];
		{y, {x}, k}]

rework[n_][{x_List, y_List}] := 
	Module[{a, m}, m = Length[y];
	a = If[m === n, y, Join[y, Table[{}, {i, n-m}]]];
	Join[x, #]& /@ a]

findheads[r_] := Union[Select[Flatten[r], RuleQ] /. (a_ -> b_) -> a]

SolveFrom[TableForm, x___List] := 
	Module[{s, f, fr, a, n}, 
	n = Max[Length[Last[#]]& /@ {x}];
	f = findheads[{x}]; fr = (# -> ".")& /@ f;
	s = rework[n] /@ (Rest /@ {x});
	a = f /. s /. fr;
	TableForm[Transpose[a], TableHeadings->{Automatic, Automatic, f}]]

SolveShow[a_List, opts___Rule] := 
	Module[{f, fr, x}, 
	f = findheads[a];
	fr = (# -> ".")& /@ f;
	x = (f /. a) /. fr;
	TableForm[Transpose[x], opts, TableHeadings -> {f, Automatic}]]





SolveGeneral[x_, {t___}] :=If[If[ListQ[x], Apply[And, x], x],
			(*True*) SequenceToRules[{t}, All], 
			(* False *) SequenceToRules[{t}, Null],
			(* otherwise *) Solve[x, {t}]]

SolveLHS[x__] := Module[{y}, y = Flatten[{x}];SolveGeneral @@ {y, First /@ y}]

Solve2List[x_List, {t___}] :=  SolveGeneral[Simplify[Apply[Equal, x]], {t}]

SortSameQ[x_, y_, test_] := test[x,y] && test[y,x]

StringListQ[var_List] := Module[{a = {}}, 
		Do[ If[ !StringQ[ var[[i]] ], AppendTo[a, i] ], {i,1,Length[var]} ];
		If[a === {}, True, a]]

StringListPralse[var_List] := 
			Module[{a}, a = StringListQ[var];
			If[ Head[a] === List, 
			Pralse["There is no string in position " <> ToString[a] ]]]

StringToList[x_String] := Module[{y},
	y = StringReplace[x, " " -> "@"];
	y = FixedPoint[StringReplace[#, "@@" -> "@"]&, y];
	ToExpression["{\""<>StringReplace[y, "@" -> "\", \""]<>"\"}"]
	](*endModule*)

ToPattern[x_List, head_:Blank] := Map[ Rule[#, Pattern[#, head[]]]&, x]

UnPattern[y_] := y /. Pattern -> Composition[First, List]


ToPiecewise::len = "Not an even number of entries"; 

Options[ToPiecewise] = {Append -> {}, Function -> Less}; 

ToPiecewise[x_Symbol, v_List, opts___Rule] := 
  Module[{f, a}, If[ !EvenQ[Length[v]], 
     Message[ToPiecewise::len]; Return[]]; 
    {f, a} = {Function, Append} /. {opts} /. Options[ToPiecewise]; 
    Which @@ 
     Flatten[Append[({f[x, #1[[1]]], #1[[2]]} & ) /@ 
        Partition[v, 2], a]]]
        


Options[ToPiecewiseLinear] = {Append -> {}, Function -> Less};
 
ToPiecewiseLinear[x_, {a0_, b0_, c0_}, rates_List, 
   opts___Rule] := 
  Module[{n, r, a, b, ff, rhs, cum, f, ap}, 
   r = rates; n = Length[r]; 
    If[ !EvenQ[n], Message[ToPiecewise::len]; Return[]]; 
    {f, ap} = 
     {Function, Append} /. {opts} /. Options[ToPiecewiseLinear]; 
     rhs = {f[x, a0], b0*x + c0}; cum = b0*a0 + c0; ff = a0; 
    Do[{a, b} = Take[r, 2]; r = Drop[r, 2]; 
      AppendTo[rhs, {f[x, a], b*(x - ff) + cum}]; 
      cum = b*(a - ff) + cum; ff = a, {i, n/2}]; 
    Which @@ Flatten[Append[rhs, ap]]]
    


XXPlusSpace[x_List, tr_:True] := Results[XXPlusSpace, tr] = 
	If[tr, 	Transpose[{Drop[x, -1], Rest[x]}],
	Rest[Partition[ Flatten[Transpose[{x, x}]], 2, 1]]]


End[]

EndPackage[]
