(*******************************************

	Cool`Transport`  package


 *******************************************)



(* :Author: Thomas Cool *)
(* :Copyright: Copyright 1997 Thomas Cool *)
(* :Package Version: 1.02,  July 1998.*)
(* :Mathematica Version: 3.0.0 *)
(* :Keywords:    *)
(* :Limitation: *)
(* :License: use of this software file requires a license usually available
      by payment of $10 to Swift account ING.B.NL.2A 3736767 to the name of 
      Thomas Cool, Rotterdamsestraat 69, 2586 GH Scheveningen, Holland.
      Please inquire about the cost of packs. See the License[] function.
 *)

Needs["Cool`Common`"]

BeginPackage["Cool`Transport`", Join[{"Cool`Physics`", "Cool`Economic`Common`"}, $Cool]]


CrashPlot::usage = "CrashPlot[x, {v1, a1}, {v2, a2}, t, l, opts___Rule] gives a plot for a crash situation, with the parameters given as in 
CrashBasedCapacity. The offset x gives the position at which vehicle 2 is when vehicle 1 starts braking.\nCrashPlot[Left, etcetera] takes the hypothetical situation that the vehicles drive next to each other, and the safe driving distance then shows up as the distance between the vehicles at full stop\nCrashPlot[Right, etcetera] shows the proper plot when vehicle 2 is at x and vehicle 1 is at x + safe driving distance"


CrashBasedCapacity::usage = "CrashBasedCapacity[{v1, a1}, {v2, a2}, TR, L] 
gives the capacity of a Freight link when the requirement is that vehicle 2 (backtrailer) does not crash into vehicle 1 (frontrunner). Vehicle i drives at vi m/s and brakes at (nonnegative) ai m/s^2. Vehicle 2 has a reaction time of TR, and the average length of the vehicles is L. It is assumed that the vehicles, while braking, do not crash before the frontrunner is fully at rest.\nCrashBasedCapacity[{v, a}, TR, L] gives the result for an average cruising speed of v and an immediate full stop of the frontrunner, i.e. CrashBasedCapacity[{v, Infinity}, {v, a}, TR, L] \n\nOutput is a list with the following rules (using text strings):\n\n\"BrakeDistance[1]\": the distance that vehicle 1 needs for braking to a full stop\n\"BrakeDistance[2]\": the distance that vehicle 2 needs for braking to a full stop\n\"BrakeTime[1]\": the time that vehicle 1 needs for braking to a full stop\n\"BrakeTime[2]\": the time that vehicle 2 needs for braking to a full stop (excl. of TR)\n\"ReactionDistance\": the distance that vehicle 2 moves during TR\n\"SafetyDistance\": the distance that the vehicles should drive apart to prevent a crash\nCrashBasedCapacity: the capacity of the link based on the safety distance and average vehicle length\n\"OptimalSpeed\": the speed that is optimal for both vehicles based on optimal capacity\n\"OptimalCapacity\": the capacity that is optimal based on the assumption of uniform speed, taking D[cap[v], v] == 0"

GridCenter::usage = "For the center, and related information, of a rectilinear grid of a list of different co-ordinates and 'masses' (forces) at those points. Similar to CenterOfGravity.\nGridCenter[{c___List}] with co-ordinates ci = {xi, yi, ..., lasti}, the last co-ordinate lasti is regarded as the mass. The output information gives 'work' (force * distance) as the minimand"

TripCostMatrix::usage = "TripCostMatrix[{c__List}, n_:1] for Euclidean 
distance measure, and\nTripCostMatrix[Right, {c__List}, n_:1] for rectilinear distance measure (right angled grid).\nTripCostMatrix[d_][{x__List}, n_:1] for any distance measure d\nWith co-ordinates ci = {xi, yi, ..., lasti}, the last co-ordinate lasti is regarded as the number of trips with the destination of the first co-ordinates. Give n = 2 for return trips, or any other value such as the cost per kilometer.\nOutput gives the distances between the co-ordinates, the cost matrix per trip, the total cost matrix, and the total costs per origin."

CostPerVKM::usage = "CostPerVKM[pt, pf, a, v_Symbol, b] gives the cost per (vehicle) kilometer for a speed of v km/h when variable (rental) costs per hour are pt, and when speed dependent costs (such as fuel) have unit cost pf and input requirements (a v^b). Output consists of three items: the general function, the optimal speed, and the minimal cost per km.\nNB.Minimal cost has been implemented by D[CostPerVKM, v] == 0 and substituting the solution in the routine for speedier answer.\nNB. Though we use km's and hours in this explanation, the units essentially are arbitrary. CostPerVKM[pt, pf, a, v, b, dim] gives the function when v is subjected to a proportional adjustment dim v, e.g. dimensional change\nNB. See CostFrom"


CostFrom::usage = "Uses output from CostPerVKM to find the distance per duration or the duration per distance:
\nCostFrom[Distance, d, CostPerVKM_List, factor:1] computes the cost from distance d
\nCostFrom[Duration, d, CostPerVKM_List, factor:1] computes the cost from duration d
\nOutput: 
\nCost: {total, {fuel independent cost, fuel dependent cost}}
\nTimes: {implied duration, implied duration / factor} where the latter is used for the cost computations
\nInput: the factor could be 24 (hours per day). If speed is given as km/hour or as knots, and fuel use is specified in use per day, then either (1) pt must be given in days too and factor = 24, or (2) fuel use must be divided by 24 and factor remains 1"

ProfitPerVKM::usage = "ProfitPerVKM[{p, q, o}, {pt, pf, a, v_Symbol, b}] 
solves for maximal profit (p q o v - o (pt + pf a v^b)) by determining optimal speed v. Note that v is an unassigned Symbol here.
\nLegend:
\no = operating time (e.g. 24 * 365 hours per year)
\nq = quantity transported (e.g. carrying capacity * loadfactor)
\np = price per weight distance (e.g. price per tonnekilometer)
\npt = price per vehicle-duration, independent of speed (e.g. rent per hour)
\npf = price per speed dependent aspects (e.g. fuel price)
\na and b are parameters for speed dependent aspects (e.g. fuel use per hour);
\nnote that you can enter a as a' g[q] so dependency upon q is possible.
\nNote that (o v) gives the operating distance of the vehicle.
\n
\nProfitPerVKM[dim][{p, q, o}, {pt, pf, a, v_Symbol, b}] helps understanding the changes to make in p and a when v is measured in different distance dimension, e.g. miles instead of kilometers, while retaining the same solution
\n
\nProfitPerVKM[{p, q, o}, {pt, pf, a, v_Symbol, b}, {H, ph, d}] performs the same computations, but now with handling time H per trip, handling cost per time ph and average distance d per trip added. The average distance has 
implications for the frequency of handling.
\n
\nProfitPerVKM[dim][{p, q, o}, {pt, pf, a, v_Symbol, b}, {H, ph, d}] helps 
indicating the changes to p, a and d when changing v's distance dimension"








Begin["`Private`"]
End[]
EndPackage[]
Print["This is a crippled package: it contains only the usage statements, no routines. Use of the proper software requires a user license.
See http://www.can.nl/~cool or write to Thomas Cool, Rotterdamsestraat 69, NL-2586 GH Scheveningen, Holland for ordering details"]
